clear all
capture log close
set more off
# delimit ;
set matsize 800 ;

/* These directories need to be changed for the files to run properly. This 
should be done in both .do files. */
sysdir set PERSONAL "C:\Ado\" ;
global DO "" ;
global INPUT "" ;
global OUTPUT "" ;
global LOGS "" ;
global FIGURES "" ;

log using "${LOGS}MW_Desc_Summary_Figures_Final.log", replace ;

/* Summary statistics for response/no response */
import excel using "${INPUT}MW_Papers_1992_2020_Final.xlsx", firstrow sheet("Author_Selections") cellrange(A1:O132) ;

rename Preferredestimate elasticity ;
rename SignificantNo105 significance ;
rename Definitionofestimate estimate_details ;
rename Group population_of_interest ;
rename Sourceinpaper estimate_location ;
rename Typeofvariation variation_type ;

replace significance="" if significance=="N/A" ;
replace significance="" if significance=="No response" ;
replace significance="" if significance=="No response?" ;
replace significance="" if significance=="Refused to provide preferred estimate" ;

replace variation_type="" if variation_type=="N/A" ;
replace variation_type="" if variation_type=="No response" ;
replace variation_type="" if variation_type=="No response?" ;
replace variation_type="" if variation_type=="Refused to provide preferred estimate" ;

drop if elasticity==. | significance=="" ;

sum elasticity, detail ;

sum elasticity if ResponsefromAuthors=="Yes" | ResponsefromAuthors=="N/A", detail ;

sum elasticity if ResponsefromAuthors=="No", detail ;

gen year_ref=year ;
replace year_ref="2021" if year_ref=="forthcoming" ;
destring year_ref, replace ;

sum year_ref, detail ;

sum year_ref if ResponsefromAuthors=="Yes" | ResponsefromAuthors=="N/A", detail ;

sum year_ref if ResponsefromAuthors=="No", detail ;

sum elasticity if year_ref<2010, detail ;

sum elasticity if year_ref>=2010, detail ;

gen authors="" ;
replace authors=author1 if author1!="" & author2=="" & author3=="" & author4=="" ;
egen forreplace2=concat(author1 author2) if author1!="" & author2!="" & author3=="" & author4=="", punct(" & ") ;
replace authors=forreplace2 if author1!="" & author2!="" & author3=="" & author4=="" ;
drop forreplace2 ;
replace authors=author1 + " et al." if author1!="" & author2!="" & author3!="" & author4=="" ;
replace authors=author1 + " et al." if author1!="" & author2!="" & author3!="" & author4!="" ;
replace authors=author1 + " et al." if author1!="" & author2!="" & author3!="" & author4!="" ;
replace authors=author1 + " et al." if author1!="" & author2!="" & author3!="" & author4!="" ;

egen yearmult=concat(year multiple) ;
replace yearmult="(" + yearmult + ")" ;
egen paper=concat(authors yearmult), punct(" ") ;
egen paper2=group(paper), label ;
drop paper ;
rename paper2 paper ;

gen young_adults=(substr(population_of_interest, 1, 4)=="Teen" | substr(population_of_interest, 1, 12)=="Young adults" | 
substr(population_of_interest, 1, 5)=="Youth" | substr(population_of_interest, 1, 18)=="Non enrolled 16-24" | 
substr(population_of_interest, 1, 18)=="Non enrolled 20-24" | substr(population_of_interest, 1, 27)=="High school dropouts, 20-24" | substr(population_of_interest, 1, 28)=="High school graduates, 20-24") ;

gen low_wage_ind=(substr(population_of_interest, 1, 11)=="All limited" | substr(population_of_interest, 1, 9)=="Fast Food" | 
substr(population_of_interest, 1, 9)=="Fast-food" | substr(population_of_interest, 1, 12)=="Full-service" | substr(population_of_interest, 1, 4)=="Farm" | 
substr(population_of_interest, 1, 7)=="Group 1" | substr(population_of_interest, 1, 7)=="Group 4" | substr(population_of_interest, 1, 5)=="NAICS" | 
substr(population_of_interest, 1, 3)=="SIC" | substr(population_of_interest, 1, 5)=="Texas" | substr(population_of_interest, 1, 10)=="Restaurant") ;

gen directly_affected=(substr(population_of_interest, 1, 8)=="Incumbent" | substr(population_of_interest, 1, 4)=="MW +" | 
substr(population_of_interest, 1, 4)=="MW -" | substr(population_of_interest, 1, 8)=="Low wage" | substr(population_of_interest, 1, 8)=="Low-wage" | 
substr(population_of_interest, 1, 3)=="w <" | substr(population_of_interest, 1, 15)=="Workers in NLSY" | population_of_interest=="Overall, relative to sample avg MW increase") ;

gen low_ed=(substr(population_of_interest, 1, 5)=="16-29" | substr(population_of_interest, 1, 10)=="HS dropout" | substr(population_of_interest, 1, 4)=="HSDO" | substr(population_of_interest, 1, 10)=="HS or less" | 
substr(population_of_interest, 1, 20)=="High school dropouts" | substr(population_of_interest, 1, 9)=="Immigrants" | substr(population_of_interest, 1, 12)=="Non enrolled" | substr(population_of_interest, 1, 14)=="Single mothers" | 
substr(population_of_interest, 1, 25)=="Young adults, 16-29, LTHS" | substr(population_of_interest, 1, 31)=="Young adults, 20-24, HS or less"  | substr(population_of_interest, 1, 23)=="Teens 16-19, no college") ;
tab population_of_interest if low_ed==1 ;

gen federal=(substr(variation_type, 1, 7)=="Federal") ;
gen state=(substr(variation_type, 1, 5)=="State") ;
gen casestudy=(substr(variation_type, 1, 10)=="Case-study") ;

sum year_ref ;
replace year_ref=year_ref-`r(mean)' ;
tab year_ref ;

reg elasticity, cluster(paper) ;
reg elasticity year_ref, cluster(paper) ;
reg elasticity young_adults low_wage_ind directly_affected low_ed, cluster(paper) ;
lincom _cons + young_adults ;
lincom _cons + low_wage_ind ;
lincom _cons + directly_affected ;
lincom _cons + low_ed ;
reg elasticity state casestudy, cluster(paper) ;
lincom _cons + state ;
lincom _cons + casestudy ;
reg elasticity state casestudy young_adults low_wage_ind directly_affected low_ed, cluster(paper) ;
lincom _cons + state ;
lincom _cons + casestudy ;
lincom _cons + young_adults ;
lincom _cons + low_wage_ind ;
lincom _cons + directly_affected ;
lincom _cons + low_ed ;

gen elasticity_disc=(elasticity<0) ;

reg elasticity_disc, cluster(paper) ;
reg elasticity_disc year_ref, cluster(paper) ;
reg elasticity_disc young_adults low_wage_ind directly_affected low_ed, cluster(paper) ;
lincom _cons + young_adults ;
lincom _cons + low_wage_ind ;
lincom _cons + directly_affected ;
lincom _cons + low_ed ;
reg elasticity_disc state casestudy, cluster(paper) ;
lincom _cons + state ;
lincom _cons + casestudy ;
reg elasticity_disc state casestudy young_adults low_wage_ind directly_affected low_ed, cluster(paper) ;
lincom _cons + state ;
lincom _cons + casestudy ;
lincom _cons + young_adults ;
lincom _cons + low_wage_ind ;
lincom _cons + directly_affected ;
lincom _cons + low_ed ;

gen elasticity_disc_ss=(elasticity<0 & (significance==".1" | significance==".05")) ;

reg elasticity_disc_ss, cluster(paper) ;
reg elasticity_disc_ss year_ref, cluster(paper) ;
reg elasticity_disc_ss young_adults low_wage_ind directly_affected low_ed, cluster(paper) ;
lincom _cons + young_adults ;
lincom _cons + low_wage_ind ;
lincom _cons + directly_affected ;
lincom _cons + low_ed ;
reg elasticity_disc_ss state casestudy, cluster(paper) ;
lincom _cons + state ;
lincom _cons + casestudy ;
reg elasticity_disc_ss state casestudy young_adults low_wage_ind directly_affected low_ed, cluster(paper) ;
lincom _cons + state ;
lincom _cons + casestudy ;
lincom _cons + young_adults ;
lincom _cons + low_wage_ind ;
lincom _cons + directly_affected ;
lincom _cons + low_ed ;


/* Including year effect */
reg elasticity, cluster(paper) ;
reg elasticity year_ref, cluster(paper) ;
lincom _cons + year_ref ;
reg elasticity year_ref young_adults low_wage_ind directly_affected low_ed, cluster(paper) ;
lincom _cons + young_adults ;
lincom _cons + low_wage_ind ;
lincom _cons + directly_affected ;
lincom _cons + low_ed ;
lincom _cons + year_ref ;
reg elasticity year_ref state casestudy, cluster(paper) ;
lincom _cons + state ;
lincom _cons + casestudy ;
lincom _cons + year_ref ;
reg elasticity year_ref state casestudy young_adults low_wage_ind directly_affected low_ed, cluster(paper) ;
lincom _cons + state ;
lincom _cons + casestudy ;
lincom _cons + young_adults ;
lincom _cons + low_wage_ind ;
lincom _cons + directly_affected ;
lincom _cons + low_ed ;
lincom _cons + year_ref ;


reg elasticity_disc, cluster(paper) ;
reg elasticity_disc year_ref, cluster(paper) ;
lincom _cons + year_ref ;
reg elasticity_disc year_ref young_adults low_wage_ind directly_affected low_ed, cluster(paper) ;
lincom _cons + young_adults ;
lincom _cons + low_wage_ind ;
lincom _cons + directly_affected ;
lincom _cons + low_ed ;
lincom _cons + year_ref ;
reg elasticity_disc year_ref state casestudy, cluster(paper) ;
lincom _cons + state ;
lincom _cons + casestudy ;
lincom _cons + year_ref ;
reg elasticity_disc year_ref state casestudy young_adults low_wage_ind directly_affected low_ed, cluster(paper) ;
lincom _cons + state ;
lincom _cons + casestudy ;
lincom _cons + young_adults ;
lincom _cons + low_wage_ind ;
lincom _cons + directly_affected ;
lincom _cons + low_ed ;
lincom _cons + year_ref ;



reg elasticity_disc_ss, cluster(paper) ;
reg elasticity_disc_ss year_ref, cluster(paper) ;
lincom _cons + year_ref ;
reg elasticity_disc_ss year_ref young_adults low_wage_ind directly_affected low_ed, cluster(paper) ;
lincom _cons + young_adults ;
lincom _cons + low_wage_ind ;
lincom _cons + directly_affected ;
lincom _cons + low_ed ;
lincom _cons + year_ref ;
reg elasticity_disc_ss year_ref state casestudy, cluster(paper) ;
lincom _cons + state ;
lincom _cons + casestudy ;
lincom _cons + year_ref ;
reg elasticity_disc_ss year_ref state casestudy young_adults low_wage_ind directly_affected low_ed, cluster(paper) ;
lincom _cons + state ;
lincom _cons + casestudy ;
lincom _cons + young_adults ;
lincom _cons + low_wage_ind ;
lincom _cons + directly_affected ;
lincom _cons + low_ed ;
lincom _cons + year_ref ;

drop _all ;
label drop _all ;


/* MEDIAN */
import excel using "${INPUT}MW_Papers_1992_2020_Final.xlsx", firstrow sheet("Author_Selections") cellrange(A1:O132) ;

rename Preferredestimate elasticity ;
rename SignificantNo105 significance ;
rename Definitionofestimate estimate_details ;
rename Group population_of_interest ;
rename Sourceinpaper estimate_location ;
rename Typeofvariation variation_type ;

replace significance="" if significance=="N/A" ;
replace significance="" if significance=="No response" ;
replace significance="" if significance=="No response?" ;
replace significance="" if significance=="Refused to provide preferred estimate" ;

replace variation_type="" if variation_type=="N/A" ;
replace variation_type="" if variation_type=="No response" ;
replace variation_type="" if variation_type=="No response?" ;
replace variation_type="" if variation_type=="Refused to provide preferred estimate" ;

drop if elasticity==. | significance=="" ;

sum elasticity, detail ;

sum elasticity if ResponsefromAuthors=="Yes" | ResponsefromAuthors=="N/A", detail ;

sum elasticity if ResponsefromAuthors=="No", detail ;

gen year_ref=year ;
replace year_ref="2021" if year_ref=="forthcoming" ;
destring year_ref, replace ;

sum year_ref, detail ;

sum year_ref if ResponsefromAuthors=="Yes" | ResponsefromAuthors=="N/A", detail ;

sum year_ref if ResponsefromAuthors=="No", detail ;

sum elasticity if year_ref<2010, detail ;

sum elasticity if year_ref>=2010, detail ;

gen young_adults=(substr(population_of_interest, 1, 4)=="Teen" | substr(population_of_interest, 1, 12)=="Young adults" | 
substr(population_of_interest, 1, 5)=="Youth" | substr(population_of_interest, 1, 18)=="Non enrolled 16-24" | 
substr(population_of_interest, 1, 18)=="Non enrolled 20-24" | substr(population_of_interest, 1, 27)=="High school dropouts, 20-24" | substr(population_of_interest, 1, 28)=="High school graduates, 20-24") ;

gen low_wage_ind=(substr(population_of_interest, 1, 11)=="All limited" | substr(population_of_interest, 1, 9)=="Fast Food" | 
substr(population_of_interest, 1, 9)=="Fast-food" | substr(population_of_interest, 1, 12)=="Full-service" | substr(population_of_interest, 1, 4)=="Farm" | 
substr(population_of_interest, 1, 7)=="Group 1" | substr(population_of_interest, 1, 7)=="Group 4" | substr(population_of_interest, 1, 5)=="NAICS" | 
substr(population_of_interest, 1, 3)=="SIC" | substr(population_of_interest, 1, 5)=="Texas" | substr(population_of_interest, 1, 10)=="Restaurant") ;

gen directly_affected=(substr(population_of_interest, 1, 8)=="Incumbent" | substr(population_of_interest, 1, 4)=="MW +" | 
substr(population_of_interest, 1, 4)=="MW -" | substr(population_of_interest, 1, 8)=="Low wage" | substr(population_of_interest, 1, 8)=="Low-wage" | 
substr(population_of_interest, 1, 3)=="w <" | substr(population_of_interest, 1, 15)=="Workers in NLSY" | population_of_interest=="Overall, relative to sample avg MW increase") ;

gen low_ed=(substr(population_of_interest, 1, 5)=="16-29" | substr(population_of_interest, 1, 10)=="HS dropout" | substr(population_of_interest, 1, 4)=="HSDO" | substr(population_of_interest, 1, 10)=="HS or less" | 
substr(population_of_interest, 1, 20)=="High school dropouts" | substr(population_of_interest, 1, 9)=="Immigrants" | substr(population_of_interest, 1, 12)=="Non enrolled" | substr(population_of_interest, 1, 14)=="Single mothers" | 
substr(population_of_interest, 1, 25)=="Young adults, 16-29, LTHS" | substr(population_of_interest, 1, 31)=="Young adults, 20-24, HS or less"  | substr(population_of_interest, 1, 23)=="Teens 16-19, no college") ;
tab population_of_interest if low_ed==1 ;

gen federal=(substr(variation_type, 1, 7)=="Federal") ;
gen state=(substr(variation_type, 1, 5)=="State") ;
gen casestudy=(substr(variation_type, 1, 10)=="Case-study") ;

drop if elasticity==. | significance=="" ;

gen authors="" ;
replace authors=author1 if author1!="" & author2=="" & author3=="" & author4=="" ;
egen forreplace2=concat(author1 author2) if author1!="" & author2!="" & author3=="" & author4=="", punct(" & ") ;
replace authors=forreplace2 if author1!="" & author2!="" & author3=="" & author4=="" ;
drop forreplace2 ;
replace authors=author1 + " et al." if author1!="" & author2!="" & author3!="" & author4=="" ;
replace authors=author1 + " et al." if author1!="" & author2!="" & author3!="" & author4!="" ;
replace authors=author1 + " et al." if author1!="" & author2!="" & author3!="" & author4!="" ;
replace authors=author1 + " et al." if author1!="" & author2!="" & author3!="" & author4!="" ;

egen yearmult=concat(year multiple) ;
replace yearmult="(" + yearmult + ")" ;
egen paper=concat(authors yearmult), punct(" ") ;
egen paper2=group(paper), label ;
drop paper ;
rename paper2 paper ;

bysort paper: egen median_elas=median(elasticity) ;
gen signo=(significance=="No") ;
gen sig10=(significance==".1") ;
gen sig5=(significance==".05") ;
bysort paper: egen total_no=sum(signo) ;
bysort paper: egen total_10=sum(sig10) ;
bysort paper: egen total_5=sum(sig5) ;
gen median_sig="" ;
replace median_sig="No" if total_10+total_5<=total_no ;
replace median_sig=".1" if (total_10+total_5>total_no) & (total_5<=total_10+total_no) ;
replace median_sig=".05" if total_5>total_10+total_no ;
tab median_sig ;

sum year_ref ;
replace year_ref=year_ref-`r(mean)' ;
tab year_ref ;

reg median_elas, cluster(paper) ;
reg median_elas year_ref, cluster(paper) ;
reg median_elas young_adults low_wage_ind directly_affected low_ed, cluster(paper) ;
lincom _cons + young_adults ;
lincom _cons + low_wage_ind ;
lincom _cons + directly_affected ;
lincom _cons + low_ed ;
reg median_elas state casestudy, cluster(paper) ;
lincom _cons + state ;
lincom _cons + casestudy ;
reg median_elas state casestudy young_adults low_wage_ind directly_affected low_ed, cluster(paper) ;
lincom _cons + state ;
lincom _cons + casestudy ;
lincom _cons + young_adults ;
lincom _cons + low_wage_ind ;
lincom _cons + directly_affected ;
lincom _cons + low_ed ;

gen median_elas_disc=(median_elas<0) ;

reg median_elas_disc, cluster(paper) ;
reg median_elas_disc year_ref, cluster(paper) ;
reg median_elas_disc young_adults low_wage_ind directly_affected low_ed, cluster(paper) ;
lincom _cons + young_adults ;
lincom _cons + low_wage_ind ;
lincom _cons + directly_affected ;
lincom _cons + low_ed ;
reg median_elas_disc state casestudy, cluster(paper) ;
lincom _cons + state ;
lincom _cons + casestudy ;
reg median_elas_disc state casestudy young_adults low_wage_ind directly_affected low_ed, cluster(paper) ;
lincom _cons + state ;
lincom _cons + casestudy ;
lincom _cons + young_adults ;
lincom _cons + low_wage_ind ;
lincom _cons + directly_affected ;
lincom _cons + low_ed ;

gen median_elas_disc_ss=(median_elas<0 & (median_sig==".1" | median_sig==".05")) ;

reg median_elas_disc_ss, cluster(paper) ;
reg median_elas_disc_ss year_ref, cluster(paper) ;
reg median_elas_disc_ss young_adults low_wage_ind directly_affected low_ed, cluster(paper) ;
lincom _cons + young_adults ;
lincom _cons + low_wage_ind ;
lincom _cons + directly_affected ;
lincom _cons + low_ed ;
reg median_elas_disc_ss state casestudy, cluster(paper) ;
lincom _cons + state ;
lincom _cons + casestudy ;
reg median_elas_disc_ss state casestudy young_adults low_wage_ind directly_affected low_ed, cluster(paper) ;
lincom _cons + state ;
lincom _cons + casestudy ;
lincom _cons + young_adults ;
lincom _cons + low_wage_ind ;
lincom _cons + directly_affected ;
lincom _cons + low_ed ;


/* Including year effect */
reg median_elas, cluster(paper) ;
reg median_elas year_ref, cluster(paper) ;
lincom _cons + year_ref ;
reg median_elas year_ref young_adults low_wage_ind directly_affected low_ed, cluster(paper) ;
lincom _cons + young_adults ;
lincom _cons + low_wage_ind ;
lincom _cons + directly_affected ;
lincom _cons + low_ed ;
lincom _cons + year_ref ;
reg median_elas year_ref state casestudy, cluster(paper) ;
lincom _cons + state ;
lincom _cons + casestudy ;
lincom _cons + year_ref ;
reg median_elas year_ref state casestudy young_adults low_wage_ind directly_affected low_ed, cluster(paper) ;
lincom _cons + state ;
lincom _cons + casestudy ;
lincom _cons + young_adults ;
lincom _cons + low_wage_ind ;
lincom _cons + directly_affected ;
lincom _cons + low_ed ;
lincom _cons + year_ref ;


reg median_elas_disc, cluster(paper) ;
reg median_elas_disc year_ref, cluster(paper) ;
lincom _cons + year_ref ;
reg median_elas_disc year_ref young_adults low_wage_ind directly_affected low_ed, cluster(paper) ;
lincom _cons + young_adults ;
lincom _cons + low_wage_ind ;
lincom _cons + directly_affected ;
lincom _cons + low_ed ;
lincom _cons + year_ref ;
reg median_elas_disc year_ref state casestudy, cluster(paper) ;
lincom _cons + state ;
lincom _cons + casestudy ;
lincom _cons + year_ref ;
reg median_elas_disc year_ref state casestudy young_adults low_wage_ind directly_affected low_ed, cluster(paper) ;
lincom _cons + state ;
lincom _cons + casestudy ;
lincom _cons + young_adults ;
lincom _cons + low_wage_ind ;
lincom _cons + directly_affected ;
lincom _cons + low_ed ;
lincom _cons + year_ref ;



reg median_elas_disc_ss, cluster(paper) ;
reg median_elas_disc_ss year_ref, cluster(paper) ;
lincom _cons + year_ref ;
reg median_elas_disc_ss year_ref young_adults low_wage_ind directly_affected low_ed, cluster(paper) ;
lincom _cons + young_adults ;
lincom _cons + low_wage_ind ;
lincom _cons + directly_affected ;
lincom _cons + low_ed ;
lincom _cons + year_ref ;
reg median_elas_disc_ss year_ref state casestudy, cluster(paper) ;
lincom _cons + state ;
lincom _cons + casestudy ;
lincom _cons + year_ref ;
reg median_elas_disc_ss year_ref state casestudy young_adults low_wage_ind directly_affected low_ed, cluster(paper) ;
lincom _cons + state ;
lincom _cons + casestudy ;
lincom _cons + young_adults ;
lincom _cons + low_wage_ind ;
lincom _cons + directly_affected ;
lincom _cons + low_ed ;
lincom _cons + year_ref ;

drop _all ;
label drop _all ;






import excel using "${INPUT}MW_Papers_1992_2020_Final.xlsx", firstrow sheet("Author_Selections") cellrange(A1:O132) ;

rename Preferredestimate elasticity ;
rename SignificantNo105 significance ;
rename Definitionofestimate estimate_details ;
rename Group population_of_interest ;
rename Sourceinpaper estimate_location ;
rename Typeofvariation variation_type ;

replace significance="" if significance=="N/A" ;
replace significance="" if significance=="No response" ;
replace significance="" if significance=="No response?" ;
replace significance="" if significance=="Refused to provide preferred estimate" ;

replace variation_type="" if variation_type=="N/A" ;
replace variation_type="" if variation_type=="No response" ;
replace variation_type="" if variation_type=="No response?" ;
replace variation_type="" if variation_type=="Refused to provide preferred estimate" ;

drop if elasticity==. | significance=="" ;

gen estimate_id=_n ;

gen authors="" ;
replace authors=author1 if author1!="" & author2=="" & author3=="" & author4=="" ;
egen forreplace2=concat(author1 author2) if author1!="" & author2!="" & author3=="" & author4=="", punct(" & ") ;
replace authors=forreplace2 if author1!="" & author2!="" & author3=="" & author4=="" ;
drop forreplace2 ;
replace authors=author1 + " et al." if author1!="" & author2!="" & author3!="" & author4=="" ;
replace authors=author1 + " et al." if author1!="" & author2!="" & author3!="" & author4!="" ;
replace authors=author1 + " et al." if author1!="" & author2!="" & author3!="" & author4!="" ;
replace authors=author1 + " et al." if author1!="" & author2!="" & author3!="" & author4!="" ;

egen yearmult=concat(year multiple) ;
replace yearmult="(" + yearmult + ")" ;
egen paper=concat(authors yearmult), punct(" ") ;
egen paper2=group(paper), label ;
drop paper ;
rename paper2 paper ;

gen year_ref=year ;
replace year_ref="2021" if year_ref=="forthcoming" ;
destring year_ref, replace ;

gen neg_elas=-elasticity ;

save "${OUTPUT}MW_Papers_1992_2020_Final.dta", replace ;

log close ;

do "${DO}MW_Desc_Author_Groups_Final.do" ;

log using "${LOGS}MW_Desc_Summary_Figures_Final.log", replace ;


/* Summary Stats for Tables 3 and 4 */
drop _all ;

use "${OUTPUT}MW_Papers_1992_2020_Final.dta" ;

gen federal=1 if substr(variation_type, 1, 7)=="Federal" ;

gen state=1 if substr(variation_type, 1, 5)=="State" ;

gen casestudy=1 if substr(variation_type, 1, 10)=="Case-study" ;

gen teens=1 if substr(population_of_interest, 1, 4)=="Teen" ;

gen young_adults=1 if substr(population_of_interest, 1, 4)=="Teen" | substr(population_of_interest, 1, 12)=="Young adults" | 
substr(population_of_interest, 1, 5)=="Youth" | substr(population_of_interest, 1, 18)=="Non enrolled 16-24" | 
substr(population_of_interest, 1, 18)=="Non enrolled 20-24" | substr(population_of_interest, 1, 27)=="High school dropouts, 20-24" | substr(population_of_interest, 1, 28)=="High school graduates, 20-24" ;

gen low_ed=1 if substr(population_of_interest, 1, 5)=="16-29" | substr(population_of_interest, 1, 10)=="HS dropout" | substr(population_of_interest, 1, 4)=="HSDO" | substr(population_of_interest, 1, 10)=="HS or less" | 
substr(population_of_interest, 1, 20)=="High school dropouts" | substr(population_of_interest, 1, 9)=="Immigrants" | substr(population_of_interest, 1, 12)=="Non enrolled" | substr(population_of_interest, 1, 14)=="Single mothers" | 
substr(population_of_interest, 1, 25)=="Young adults, 16-29, LTHS" | substr(population_of_interest, 1, 31)=="Young adults, 20-24, HS or less"  | substr(population_of_interest, 1, 23)=="Teens 16-19, no college" ;

gen low_wage_ind=1 if substr(population_of_interest, 1, 11)=="All limited" | substr(population_of_interest, 1, 9)=="Fast Food" | 
substr(population_of_interest, 1, 9)=="Fast-food" | substr(population_of_interest, 1, 12)=="Full-service" | substr(population_of_interest, 1, 4)=="Farm" | 
substr(population_of_interest, 1, 7)=="Group 1" | substr(population_of_interest, 1, 7)=="Group 4" | substr(population_of_interest, 1, 5)=="NAICS" | 
substr(population_of_interest, 1, 3)=="SIC" | substr(population_of_interest, 1, 5)=="Texas" | substr(population_of_interest, 1, 10)=="Restaurant" ;

gen low_wage_group=1 if substr(population_of_interest, 1, 8)=="Incumbent" | substr(population_of_interest, 1, 4)=="MW +" | 
substr(population_of_interest, 1, 4)=="MW -" | substr(population_of_interest, 1, 8)=="Low wage" | substr(population_of_interest, 1, 8)=="Low-wage" | substr(population_of_interest, 1, 3)=="w <" | 
population_of_interest=="Overall, relative to sample avg MW increase" ;

foreach y in federal state casestudy teens young_adults low_ed low_wage_ind low_wage_group { ;

	tab `y' ;
	
} ;

foreach y in federal state casestudy { ;

	foreach x in teens young_adults low_ed low_wage_ind low_wage_group { ;
	
		display "`y' `x'" ;
		tab `y' if `x'==1 ;
		
	} ;
	
} ;

drop _all ;

/* Now, we create each of the figures in the paper. */

use "${OUTPUT}MW_Papers_1992_2020_Final.dta" ;

/* All Elasticities */
drop if elasticity==. | significance=="" ;

sort neg_elas authorgroup ;
gen order=_n ;

sum elasticity if elasticity!=., detail ;
local median_elas=`r(p50)' ;
local median_elas=round(`median_elas', 0.001) ;
local mean_elas=`r(mean)' ;
local mean_elas=round(`mean_elas', 0.001) ;
count if elasticity!=. ;

sum elasticity if elasticity!=. & year_ref<2010, detail ;
local median_elas_bef_2010=`r(p50)' ;
local mean_elas_bef_2010=`r(mean)' ;

sum elasticity if elasticity!=. & year_ref>=2010, detail ;
local median_elas_2010_onw=`r(p50)' ;
local mean_elas_2010_onw=`r(mean)' ;

display "`median_elas_bef_2010' `median_elas_2010_onw' `mean_elas_bef_2010' `mean_elas_2010_onw'" ;
decode paper, gen(paper_name) ;
replace paper_name="Kim & Taylor (1995)" if paper_name=="T Kim & Taylor (1995)" ;
replace paper_name="Kim & Jang (2020)" if paper_name=="HS Kim & Jang (2020)" ;
replace paper_name="Kandilov & Kandilov (forth.)" if paper_name=="Kandilov & Kandilov (forthcoming" ;
replace paper_name="Gopalan et al. (forth.)" if paper_name=="Gopalan et al. (forthcoming)" ;
replace paper_name="Bailey et al. (forth.)" if paper_name=="Bailey et al. (forthcoming)" ;
replace paper_name="Derenoncourt & Montialoux (forth.)" if paper_name=="Derenoncourt & Montialoux (forth" ;
replace paper_name="Gilyard & Podemska-Mikluch (2020)" if paper_name=="Gilyard & Podemska-Mikluch (2020" ;

count ;
forvalues y=1(1)`r(N)' { ;

	local paper`y'=paper_name[`y'] ;
	
} ;

count ;
count if elasticity<0 ;
count if elasticity<0 & (significance==".1" | significance==".05") ;
count if elasticity<0 & significance==".05" ;
count if elasticity>=0 ;
count if elasticity>=0 & (significance==".1" | significance==".05") ;
count if elasticity>=0 & significance==".05" ;

count if year_ref<2010 ;
count if elasticity<0 & year_ref<2010 ;
count if elasticity<0 & (significance==".1" | significance==".05") & year_ref<2010 ;
count if elasticity<0 & significance==".05" & year_ref<2010 ;
count if elasticity>=0 & year_ref<2010 ;
count if elasticity>=0 & (significance==".1" | significance==".05") & year_ref<2010 ;
count if elasticity>=0 & significance==".05" & year_ref<2010 ;

count if year_ref>=2010 ;
count if elasticity<0 & year_ref>=2010 ;
count if elasticity<0 & (significance==".1" | significance==".05") & year_ref>=2010 ;
count if elasticity<0 & significance==".05" & year_ref>=2010 ;
count if elasticity>=0 & year_ref>=2010 ;
count if elasticity>=0 & (significance==".1" | significance==".05") & year_ref>=2010 ;
count if elasticity>=0 & significance==".05" & year_ref>=2010 ;

display "Mean elasicity = `mean_elas'" ;
display "Median elasticity = `median_elas'" ;
twoway (bar elasticity order if significance=="No", horizontal color(gs12)) (bar elasticity order if significance==".1",  horizontal color(gs6)) (bar elasticity order if significance==".05", horizontal color(gs0)), xscale(range(-1(0.1)1.8)) xlabel(-1(0.5)1.5) xmtick(-1(0.1)1.8) xline(0, lpattern(solid) lcolor(black) lwidth(medthick)) xline(`mean_elas', lpattern(dash) lcolor(black) lwidth(medthin)) xline(`median_elas', lpattern(dot) lcolor(black) lwidth(medthin))
ylabel(1 "`paper1'" 2 "`paper2'" 3 "`paper3'" 4 "`paper4'" 5 "`paper5'" 6 "`paper6'" 7 "`paper7'" 8 "`paper8'" 9 "`paper9'" 10 "`paper10'" 11 "`paper11'" 12 "`paper12'" 13 "`paper13'" 14 "`paper14'" 15 "`paper15'" 16 "`paper16'" 17 "`paper17'" 18 "`paper18'" 19 "`paper19'" 20 "`paper20'" 21 "`paper21'" 22 "`paper22'" 23 "`paper23'" 24 "`paper24'" 25 "`paper25'" 26 "`paper26'" 27 "`paper27'" 28 "`paper28'" 29 "`paper29'" 30 "`paper30'" 31 "`paper31'" 32 "`paper32'" 33 "`paper33'" 34 "`paper34'" 35 "`paper35'" 36 "`paper36'" 37 "`paper37'" 38 "`paper38'" 39 "`paper39'" 40 "`paper40'" 41 "`paper41'" 42 "`paper42'" 43 "`paper43'" 44 "`paper44'" 45 "`paper45'" 46 "`paper46'" 47 "`paper47'" 48 "`paper48'" 49 "`paper49'" 50 "`paper50'" 51 "`paper51'" 52 "`paper52'" 53 "`paper53'" 54 "`paper54'" 55 "`paper55'" 56 "`paper56'" 57 "`paper57'" 58 "`paper58'" 59 "`paper59'" 60 "`paper60'" 61 "`paper61'" 62 "`paper62'" 63 "`paper63'" 64 "`paper64'" 65 "`paper65'" 66 "`paper66'" 67 "`paper67'" 68 "`paper68'" 69 "`paper69'" 70 "`paper70'" 71 "`paper71'" 72 "`paper72'" 73 "`paper73'" 74 "`paper74'" 75 "`paper75'" 76 "`paper76'" 77 "`paper77'" 78 "`paper78'" 79 "`paper79'" 80 "`paper80'" 81 "`paper81'" 82 "`paper82'" 83 "`paper83'" 84 "`paper84'" 85 "`paper85'" 86 "`paper86'" 87 "`paper87'" 88 "`paper88'" 89 "`paper89'" 90 "`paper90'" 91 "`paper91'" 92 "`paper92'" 93 "`paper93'" 94 "`paper94'" 95 "`paper95'" 96 "`paper96'" 97 "`paper97'" 98 "`paper98'" 99 "`paper99'" 100 "`paper100'" 101 "`paper101'" 102 "`paper102'" 103 "`paper103'" 104 "`paper104'" 105 "`paper105'" 106 "`paper106'" 107 "`paper107'" 108 "`paper108'" 109 "`paper109'" 110 "`paper110'" 111 "`paper111'" 112 "`paper112'" 113 "`paper113'" 114 "`paper114'" 115 "`paper115'" 116 "`paper116'" 117 "`paper117'" 118 "`paper118'" 119 "`paper119'" 120 "`paper120'" 121 "`paper121'" 122 "`paper122'" 123 "`paper123'" 124 "`paper124'" 125 "`paper125'" 126 "`paper126'" 127 "`paper127'" 128 "`paper128'" 129 "`paper129'" 130 "`paper130'", angle(0) labsize(half_tiny))
title("") ytitle("") xtitle("Elasticity Estimate", size(vsmall)) legend(label(1 "Insignificant") label(2 "Marginally (10%) Significant") label(3 "Statistically (5%) Significant")) legend(size(tiny)) legend(cols(1) rows(3)) legend(position(2) ring(0))
graphregion(color(white)) ;
graph export "${FIGURES}Figure1_Preferred_Elasticities_Final.png", width(8000) replace ;
graph close ;

drop _all ;

/* Chronological Order */
use "${OUTPUT}MW_Papers_1992_2020_Final.dta" ;

drop if elasticity==. | significance=="" ;
replace year="2021" if year=="forthcoming" ;
destring year, replace ;
replace year=-year ;
gen multiple2=0 ;
replace multiple2=2 if multiple=="a" ;
replace multiple2=1 if multiple=="b" ;

sort year multiple2 authorgroup ;
gen order=_n ;

sum elasticity if elasticity!=., detail ;
local median_elas=`r(p50)' ;
local median_elas=round(`median_elas', 0.001) ;
local mean_elas=`r(mean)' ;
local mean_elas=round(`mean_elas', 0.001) ;
count if elasticity!=. ;

sum elasticity if elasticity!=. & year_ref<2010, detail ;
local median_elas_bef_2010=`r(p50)' ;
local mean_elas_bef_2010=`r(mean)' ;

sum elasticity if elasticity!=. & year_ref>=2010, detail ;
local median_elas_2010_onw=`r(p50)' ;
local mean_elas_2010_onw=`r(mean)' ;

display "`median_elas_bef_2010' `median_elas_2010_onw' `mean_elas_bef_2010' `mean_elas_2010_onw'" ;
gen year_2=-year ;
sum year_2 ;
sum elasticity ;
reg elasticity year_2 ;


decode paper, gen(paper_name) ;
replace paper_name="Kim & Taylor (1995)" if paper_name=="T Kim & Taylor (1995)" ;
replace paper_name="Kim & Jang (2020)" if paper_name=="HS Kim & Jang (2020)" ;
replace paper_name="Kandilov & Kandilov (forth.)" if paper_name=="Kandilov & Kandilov (forthcoming" ;
replace paper_name="Gopalan et al. (forth.)" if paper_name=="Gopalan et al. (forthcoming)" ;
replace paper_name="Gilyard & Podemska-Mikluch (2020)" if paper_name=="Gilyard & Podemska-Mikluch (2020" ;

count ;
forvalues y=1(1)`r(N)' { ;

	local paper`y'=paper_name[`y'] ;
	
} ;

count ;
count if elasticity<0 ;
count if elasticity<0 & (significance==".1" | significance==".05") ;
count if elasticity<0 & significance==".05" ;
count if elasticity>=0 ;
count if elasticity>=0 & (significance==".1" | significance==".05") ;
count if elasticity>=0 & significance==".05" ;

count if year_ref<2010 ;
count if elasticity<0 & year_ref<2010 ;
count if elasticity<0 & (significance==".1" | significance==".05") & year_ref<2010 ;
count if elasticity<0 & significance==".05" & year_ref<2010 ;
count if elasticity>=0 & year_ref<2010 ;
count if elasticity>=0 & (significance==".1" | significance==".05") & year_ref<2010 ;
count if elasticity>=0 & significance==".05" & year_ref<2010 ;

count if year_ref>=2010 ;
count if elasticity<0 & year_ref>=2010 ;
count if elasticity<0 & (significance==".1" | significance==".05") & year_ref>=2010 ;
count if elasticity<0 & significance==".05" & year_ref>=2010 ;
count if elasticity>=0 & year_ref>=2010 ;
count if elasticity>=0 & (significance==".1" | significance==".05") & year_ref>=2010 ;
count if elasticity>=0 & significance==".05" & year_ref>=2010 ;


display "Mean elasicity = `mean_elas'" ;
display "Median elasticity = `median_elas'" ;
twoway (bar elasticity order if significance=="No", horizontal color(gs12)) (bar elasticity order if significance==".1",  horizontal color(gs6)) (bar elasticity order if significance==".05", horizontal color(gs0)), xscale(range(-1(0.1)1.8)) xlabel(-1(0.5)1.5) xmtick(-1(0.1)1.8) xline(0, lpattern(solid) lcolor(black) lwidth(medthick)) xline(`mean_elas', lpattern(dash) lcolor(black) lwidth(medthin)) xline(`median_elas', lpattern(dot) lcolor(black) lwidth(medthin))
ylabel(1 "`paper1'" 2 "`paper2'" 3 "`paper3'" 4 "`paper4'" 5 "`paper5'" 6 "`paper6'" 7 "`paper7'" 8 "`paper8'" 9 "`paper9'" 10 "`paper10'" 11 "`paper11'" 12 "`paper12'" 13 "`paper13'" 14 "`paper14'" 15 "`paper15'" 16 "`paper16'" 17 "`paper17'" 18 "`paper18'" 19 "`paper19'" 20 "`paper20'" 21 "`paper21'" 22 "`paper22'" 23 "`paper23'" 24 "`paper24'" 25 "`paper25'" 26 "`paper26'" 27 "`paper27'" 28 "`paper28'" 29 "`paper29'" 30 "`paper30'" 31 "`paper31'" 32 "`paper32'" 33 "`paper33'" 34 "`paper34'" 35 "`paper35'" 36 "`paper36'" 37 "`paper37'" 38 "`paper38'" 39 "`paper39'" 40 "`paper40'" 41 "`paper41'" 42 "`paper42'" 43 "`paper43'" 44 "`paper44'" 45 "`paper45'" 46 "`paper46'" 47 "`paper47'" 48 "`paper48'" 49 "`paper49'" 50 "`paper50'" 51 "`paper51'" 52 "`paper52'" 53 "`paper53'" 54 "`paper54'" 55 "`paper55'" 56 "`paper56'" 57 "`paper57'" 58 "`paper58'" 59 "`paper59'" 60 "`paper60'" 61 "`paper61'" 62 "`paper62'" 63 "`paper63'" 64 "`paper64'" 65 "`paper65'" 66 "`paper66'" 67 "`paper67'" 68 "`paper68'" 69 "`paper69'" 70 "`paper70'" 71 "`paper71'" 72 "`paper72'" 73 "`paper73'" 74 "`paper74'" 75 "`paper75'" 76 "`paper76'" 77 "`paper77'" 78 "`paper78'" 79 "`paper79'" 80 "`paper80'" 81 "`paper81'" 82 "`paper82'" 83 "`paper83'" 84 "`paper84'" 85 "`paper85'" 86 "`paper86'" 87 "`paper87'" 88 "`paper88'" 89 "`paper89'" 90 "`paper90'" 91 "`paper91'" 92 "`paper92'" 93 "`paper93'" 94 "`paper94'" 95 "`paper95'" 96 "`paper96'" 97 "`paper97'" 98 "`paper98'" 99 "`paper99'" 100 "`paper100'" 101 "`paper101'" 102 "`paper102'" 103 "`paper103'" 104 "`paper104'" 105 "`paper105'" 106 "`paper106'" 107 "`paper107'" 108 "`paper108'" 109 "`paper109'" 110 "`paper110'" 111 "`paper111'" 112 "`paper112'" 113 "`paper113'" 114 "`paper114'" 115 "`paper115'" 116 "`paper116'" 117 "`paper117'" 118 "`paper118'" 119 "`paper119'" 120 "`paper120'" 121 "`paper121'" 122 "`paper122'" 123 "`paper123'" 124 "`paper124'" 125 "`paper125'" 126 "`paper126'" 127 "`paper127'" 128 "`paper128'" 129 "`paper129'" 130 "`paper130'", angle(0) labsize(half_tiny))
ytitle("") xtitle("Elasticity Estimate", size(vsmall)) legend(label(1 "Insignificant") label(2 "Marginally (10%) Significant") label(3 "Statistically (5%) Significant")) legend(size(tiny)) legend(cols(1) rows(3)) legend(position(3) ring(0))
graphregion(color(white)) ;
graph export "${FIGURES}Figure2_Chronological_Preferred_Elasticities_Final.png", width(8000) replace ;
graph close ;

drop _all ;


/* This section focuses only on estimates coming from teenagers, i.e. only those
age 19 or below. */
use "${OUTPUT}MW_Papers_1992_2020_Final.dta" ;

drop if elasticity==. | significance=="" ;

gen teens=1 if substr(population_of_interest, 1, 4)=="Teen" ;
tab teens ;
sum elasticity if teens==1, detail ;
local median_elas=`r(p50)' ;
local median_elas=round(`median_elas', 0.001) ;
local mean_elas=`r(mean)' ;
local mean_elas=round(`mean_elas', 0.001) ;

sum elasticity if teens==1 & year_ref<2010, detail ;
local median_elas_bef_2010=`r(p50)' ;
local mean_elas_bef_2010=`r(mean)' ;

sum elasticity if teens==1 & year_ref>=2010, detail ;
local median_elas_2010_onw=`r(p50)' ;
local mean_elas_2010_onw=`r(mean)' ;

display "`median_elas_bef_2010' `median_elas_2010_onw' `mean_elas_bef_2010' `mean_elas_2010_onw'" ;
keep if teens==1 ;
tab groupname ;
sort neg_elas authorgroup ;
gen order=_n ;

decode paper, gen(paper_name) ;
replace paper_name="Kim & Taylor (1995)" if paper_name=="T Kim & Taylor (1995)" ;
replace paper_name="Kim & Jang (2020)" if paper_name=="HS Kim & Jang (2020)" ;
replace paper_name="Kandilov & Kandilov (forth.)" if paper_name=="Kandilov & Kandilov (forthcoming" ;
replace paper_name="Gopalan et al. (forth.)" if paper_name=="Gopalan et al. (forthcoming)" ;
replace paper_name="Bailey et al. (forth.)" if paper_name=="Bailey et al. (forthcoming)" ;
replace paper_name="Derenoncourt & Montialoux (forth.)" if paper_name=="Derenoncourt & Montialoux (forth" ;
replace paper_name="Gilyard & Podemska-Mikluch (2020)" if paper_name=="Gilyard & Podemska-Mikluch (2020" ;

count ;
forvalues y=1(1)`r(N)' { ;

	local paper`y'=paper_name[`y'] ;
	
} ;

count ;
count if elasticity<0 ;
count if elasticity<0 & (significance==".1" | significance==".05") ;
count if elasticity<0 & significance==".05" ;
count if elasticity>=0 ;
count if elasticity>=0 & (significance==".1" | significance==".05") ;
count if elasticity>=0 & significance==".05" ;

count if year_ref<2010 ;
count if elasticity<0 & year_ref<2010 ;
count if elasticity<0 & (significance==".1" | significance==".05") & year_ref<2010 ;
count if elasticity<0 & significance==".05" & year_ref<2010 ;
count if elasticity>=0 & year_ref<2010 ;
count if elasticity>=0 & (significance==".1" | significance==".05") & year_ref<2010 ;
count if elasticity>=0 & significance==".05" & year_ref<2010 ;

count if year_ref>=2010 ;
count if elasticity<0 & year_ref>=2010 ;
count if elasticity<0 & (significance==".1" | significance==".05") & year_ref>=2010 ;
count if elasticity<0 & significance==".05" & year_ref>=2010 ;
count if elasticity>=0 & year_ref>=2010 ;
count if elasticity>=0 & (significance==".1" | significance==".05") & year_ref>=2010 ;
count if elasticity>=0 & significance==".05" & year_ref>=2010 ;


display "Mean elasicity = `mean_elas'" ;
display "Median elasticity = `median_elas'" ;
twoway (bar elasticity order if significance=="No", horizontal color(gs12)) (bar elasticity order if significance==".1", horizontal color(gs6)) (bar elasticity order if significance==".05", horizontal color(gs0)), xscale(range(-1(0.1)0.6)) xlabel(-1(0.5)0.5) xmtick(-1(0.1)0.6) xline(0, lpattern(solid) lcolor(black) lwidth(medthick)) xline(`mean_elas', lpattern(dash) lcolor(black) lwidth(medthin)) xline(`median_elas', lpattern(dot) lcolor(black) lwidth(medthin))
ylabel(1 "`paper1'" 2 "`paper2'" 3 "`paper3'" 4 "`paper4'" 5 "`paper5'" 6 "`paper6'" 7 "`paper7'" 8 "`paper8'" 9 "`paper9'" 10 "`paper10'" 11 "`paper11'" 12 "`paper12'" 13 "`paper13'" 14 "`paper14'" 15 "`paper15'" 16 "`paper16'" 17 "`paper17'" 18 "`paper18'" 19 "`paper19'" 20 "`paper20'" 21 "`paper21'" 22 "`paper22'" 23 "`paper23'" 24 "`paper24'" 25 "`paper25'" 26 "`paper26'" 27 "`paper27'" 28 "`paper28'" 29 "`paper29'" 30 "`paper30'" 31 "`paper31'" 32 "`paper32'" 33 "`paper33'" 34 "`paper34'" 35 "`paper35'" 36 "`paper36'" 37 "`paper37'" 38 "`paper38'" 39 "`paper39'" 40 "`paper40'" 41 "`paper41'" 42 "`paper42'" 43 "`paper43'" 44 "`paper44'" 45 "`paper45'", angle(0) labsize(tiny))
ytitle("") xtitle("Elasticity Estimate", size(vsmall)) legend(label(1 "Insignificant") label(2 "Marginally (10%) Significant") label(3 "Statistically (5%) Significant")) legend(size(tiny)) legend(cols(1) rows(3)) legend(position(2) ring(0))
graphregion(color(white)) ;
graph export "${FIGURES}Figure7_Preferred_Teen_Elasticities_Final.png", width(8000) replace ;
graph close ;

drop _all ;

/* This section creates a graph for teens, and young workers. Essentially, any 
estimate that restricts their group to some category of workers under the age of 25. */
use "${OUTPUT}MW_Papers_1992_2020_Final.dta" ;

drop if elasticity==. | significance=="" ;

gen young_adults=1 if substr(population_of_interest, 1, 4)=="Teen" | substr(population_of_interest, 1, 12)=="Young adults" | 
substr(population_of_interest, 1, 5)=="Youth" | substr(population_of_interest, 1, 18)=="Non enrolled 16-24" | 
substr(population_of_interest, 1, 18)=="Non enrolled 20-24" | substr(population_of_interest, 1, 27)=="High school dropouts, 20-24" | substr(population_of_interest, 1, 28)=="High school graduates, 20-24" ;
tab young_adults ;
sum elasticity if young_adults==1, detail ;
local median_elas=`r(p50)' ;
local median_elas=round(`median_elas', 0.001) ;
local mean_elas=`r(mean)' ;
local mean_elas=round(`mean_elas', 0.001) ;

sum elasticity if young_adults==1 & year_ref<2010, detail ;
local median_elas_bef_2010=`r(p50)' ;
local mean_elas_bef_2010=`r(mean)' ;

sum elasticity if young_adults==1 & year_ref>=2010, detail ;
local median_elas_2010_onw=`r(p50)' ;
local mean_elas_2010_onw=`r(mean)' ;

display "`median_elas_bef_2010' `median_elas_2010_onw' `mean_elas_bef_2010' `mean_elas_2010_onw'" ;
keep if young_adults==1 ;
tab groupname ;
sort neg_elas authorgroup ;
gen order=_n ;

decode paper, gen(paper_name) ;
replace paper_name="Kim & Taylor (1995)" if paper_name=="T Kim & Taylor (1995)" ;
replace paper_name="Kim & Jang (2020)" if paper_name=="HS Kim & Jang (2020)" ;
replace paper_name="Kandilov & Kandilov (forth.)" if paper_name=="Kandilov & Kandilov (forthcoming" ;
replace paper_name="Gopalan et al. (forth.)" if paper_name=="Gopalan et al. (forthcoming)" ;
replace paper_name="Bailey et al. (forth.)" if paper_name=="Bailey et al. (forthcoming)" ;
replace paper_name="Derenoncourt & Montialoux (forth.)" if paper_name=="Derenoncourt & Montialoux (forth" ;
replace paper_name="Gilyard & Podemska-Mikluch (2020)" if paper_name=="Gilyard & Podemska-Mikluch (2020" ;

count ;
forvalues y=1(1)`r(N)' { ;

	local paper`y'=paper_name[`y'] ;
	
} ;

count ;
count if elasticity<0 ;
count if elasticity<0 & (significance==".1" | significance==".05") ;
count if elasticity<0 & significance==".05" ;
count if elasticity>=0 ;
count if elasticity>=0 & (significance==".1" | significance==".05") ;
count if elasticity>=0 & significance==".05" ;

count if year_ref<2010 ;
count if elasticity<0 & year_ref<2010 ;
count if elasticity<0 & (significance==".1" | significance==".05") & year_ref<2010 ;
count if elasticity<0 & significance==".05" & year_ref<2010 ;
count if elasticity>=0 & year_ref<2010 ;
count if elasticity>=0 & (significance==".1" | significance==".05") & year_ref<2010 ;
count if elasticity>=0 & significance==".05" & year_ref<2010 ;

count if year_ref>=2010 ;
count if elasticity<0 & year_ref>=2010 ;
count if elasticity<0 & (significance==".1" | significance==".05") & year_ref>=2010 ;
count if elasticity<0 & significance==".05" & year_ref>=2010 ;
count if elasticity>=0 & year_ref>=2010 ;
count if elasticity>=0 & (significance==".1" | significance==".05") & year_ref>=2010 ;
count if elasticity>=0 & significance==".05" & year_ref>=2010 ;

display "Mean elasicity = `mean_elas'" ;
display "Median elasticity = `median_elas'" ;
twoway (bar elasticity order if significance=="No", horizontal color(gs12)) (bar elasticity order if significance==".1", horizontal color(gs6)) (bar elasticity order if significance==".05", horizontal color(gs0)), xscale(range(-1(0.1)0.6)) xlabel(-1(0.5)0.5) xmtick(-1(0.1)0.6) xline(0, lpattern(solid) lcolor(black) lwidth(medthick)) xline(`mean_elas', lpattern(dash) lcolor(black) lwidth(medthin)) xline(`median_elas', lpattern(dot) lcolor(black) lwidth(medthin))
ylabel(1 "`paper1'" 2 "`paper2'" 3 "`paper3'" 4 "`paper4'" 5 "`paper5'" 6 "`paper6'" 7 "`paper7'" 8 "`paper8'" 9 "`paper9'" 10 "`paper10'" 11 "`paper11'" 12 "`paper12'" 13 "`paper13'" 14 "`paper14'" 15 "`paper15'" 16 "`paper16'" 17 "`paper17'" 18 "`paper18'" 19 "`paper19'" 20 "`paper20'" 21 "`paper21'" 22 "`paper22'" 23 "`paper23'" 24 "`paper24'" 25 "`paper25'" 26 "`paper26'" 27 "`paper27'" 28 "`paper28'" 29 "`paper29'" 30 "`paper30'" 31 "`paper31'" 32 "`paper32'" 33 "`paper33'" 34 "`paper34'" 35 "`paper35'" 36 "`paper36'" 37 "`paper37'" 38 "`paper38'" 39 "`paper39'" 40 "`paper40'" 41 "`paper41'" 42 "`paper42'" 43 "`paper43'" 44 "`paper44'" 45 "`paper45'" 46 "`paper46'" 47 "`paper47'" 48 "`paper48'" 49 "`paper49'" 50 "`paper50'" 51 "`paper51'" 52 "`paper52'" 53 "`paper53'" 54 "`paper54'" 55 "`paper55'" 56 "`paper56'" 57 "`paper57'" 58 "`paper58'" 59 "`paper59'" 60 "`paper60'" 61 "`paper61'" 62 "`paper62'" 63 "`paper63'", angle(0) labsize(tiny))
ytitle("") xtitle("Elasticity Estimate", size(vsmall)) legend(label(1 "Insignificant") label(2 "Marginally (10%) Significant") label(3 "Statistically (5%) Significant")) legend(size(tiny)) legend(cols(1) rows(3)) legend(position(2) ring(0))
graphregion(color(white)) ;
graph export "${FIGURES}Figure8_Young_Adult_Elasticities_Final.png", width(8000) replace ;
graph close ;

drop _all ;

/* Here, we look at low-wage industries. */
use "${OUTPUT}MW_Papers_1992_2020_Final.dta" ;

drop if elasticity==. | significance=="" ;

gen low_wage_ind=1 if substr(population_of_interest, 1, 11)=="All limited" | substr(population_of_interest, 1, 9)=="Fast Food" | 
substr(population_of_interest, 1, 9)=="Fast-food" | substr(population_of_interest, 1, 12)=="Full-service" | substr(population_of_interest, 1, 4)=="Farm" | 
substr(population_of_interest, 1, 7)=="Group 1" | substr(population_of_interest, 1, 7)=="Group 4" | substr(population_of_interest, 1, 5)=="NAICS" | 
substr(population_of_interest, 1, 3)=="SIC" | substr(population_of_interest, 1, 5)=="Texas" | substr(population_of_interest, 1, 10)=="Restaurant" ;
tab low_wage_ind ;
tab author1 if low_wage_ind==1 ;
sum elasticity if low_wage_ind==1, detail ;
local median_elas=`r(p50)' ;
local median_elas=round(`median_elas', 0.001) ;
local mean_elas=`r(mean)' ;
local mean_elas=round(`mean_elas', 0.001) ;

sum elasticity if low_wage_ind==1 & year_ref<2010, detail ;
local median_elas_bef_2010=`r(p50)' ;
local mean_elas_bef_2010=`r(mean)' ;

sum elasticity if low_wage_ind==1 & year_ref>=2010, detail ;
local median_elas_2010_onw=`r(p50)' ;
local mean_elas_2010_onw=`r(mean)' ;

display "`median_elas_bef_2010' `median_elas_2010_onw' `mean_elas_bef_2010' `mean_elas_2010_onw'" ;
keep if low_wage_ind==1 ;
tab groupname ;
sort neg_elas authorgroup ;
gen order=_n ;

decode paper, gen(paper_name) ;
replace paper_name="Kim & Taylor (1995)" if paper_name=="T Kim & Taylor (1995)" ;
replace paper_name="Kim & Jang (2020)" if paper_name=="HS Kim & Jang (2020)" ;
replace paper_name="Kandilov & Kandilov (forth.)" if paper_name=="Kandilov & Kandilov (forthcoming" ;
replace paper_name="Gopalan et al. (forth.)" if paper_name=="Gopalan et al. (forthcoming)" ;
replace paper_name="Bailey et al. (forth.)" if paper_name=="Bailey et al. (forthcoming)" ;
replace paper_name="Derenoncourt & Montialoux (forth.)" if paper_name=="Derenoncourt & Montialoux (forth" ;
replace paper_name="Gilyard & Podemska-Mikluch (2020)" if paper_name=="Gilyard & Podemska-Mikluch (2020" ;

count ;
forvalues y=1(1)`r(N)' { ;

	local paper`y'=paper_name[`y'] ;
	
} ;

count ;
count if elasticity<0 ;
count if elasticity<0 & (significance==".1" | significance==".05") ;
count if elasticity<0 & significance==".05" ;
count if elasticity>=0 ;
count if elasticity>=0 & (significance==".1" | significance==".05") ;
count if elasticity>=0 & significance==".05" ;

count if year_ref<2010 ;
count if elasticity<0 & year_ref<2010 ;
count if elasticity<0 & (significance==".1" | significance==".05") & year_ref<2010 ;
count if elasticity<0 & significance==".05" & year_ref<2010 ;
count if elasticity>=0 & year_ref<2010 ;
count if elasticity>=0 & (significance==".1" | significance==".05") & year_ref<2010 ;
count if elasticity>=0 & significance==".05" & year_ref<2010 ;

count if year_ref>=2010 ;
count if elasticity<0 & year_ref>=2010 ;
count if elasticity<0 & (significance==".1" | significance==".05") & year_ref>=2010 ;
count if elasticity<0 & significance==".05" & year_ref>=2010 ;
count if elasticity>=0 & year_ref>=2010 ;
count if elasticity>=0 & (significance==".1" | significance==".05") & year_ref>=2010 ;
count if elasticity>=0 & significance==".05" & year_ref>=2010 ;

display "Mean elasicity = `mean_elas'" ;
display "Median elasticity = `median_elas'" ;
twoway (bar elasticity order if significance=="No", horizontal color(gs12)) (bar elasticity order if significance==".1", horizontal color(gs6)) (bar elasticity order if significance==".05", horizontal color(gs0)), xscale(range(-1(0.1)1.8)) xlabel(-1(0.5)1.5) xmtick(-1(0.1)1.8) xline(0, lpattern(solid) lcolor(black) lwidth(medthick)) xline(`mean_elas', lpattern(dash) lcolor(black) lwidth(medthin)) xline(`median_elas', lpattern(dot) lcolor(black) lwidth(medthin))
ylabel(1 "`paper1'" 2 "`paper2'" 3 "`paper3'" 4 "`paper4'" 5 "`paper5'" 6 "`paper6'" 7 "`paper7'" 8 "`paper8'" 9 "`paper9'" 10 "`paper10'" 11 "`paper11'" 12 "`paper12'" 13 "`paper13'" 14 "`paper14'" 15 "`paper15'" 16 "`paper16'" 17 "`paper17'" 18 "`paper18'" 19 "`paper19'" 20 "`paper20'" 21 "`paper21'" 22 "`paper22'" 23 "`paper23'" 24 "`paper24'" 25 "`paper25'" 26 "`paper26'" 27 "`paper27'" 28 "`paper28'" 29 "`paper29'" 30 "`paper30'" 31 "`paper31'", angle(0) labsize(tiny))
ytitle("") xtitle("Elasticity Estimate", size(vsmall)) legend(label(1 "Insignificant") label(2 "Marginally (10%) Significant") label(3 "Statistically (5%) Significant")) legend(size(tiny)) legend(cols(1) rows(3)) legend(position(2) ring(0)) 
graphregion(color(white)) ;
graph export "${FIGURES}Figure10_Low_Wage_Industries_Elasticities_Final.png", width(8000) replace ;
graph close ;

drop _all ;


/* Here, we break out the low-wage worker categories from Figure 2C into three distinct groups: young workers, low-ed workers, and explicitly low-wage workers. */
use "${OUTPUT}MW_Papers_1992_2020_Final.dta" ;

drop if elasticity==. | significance=="" ;

gen low_wage_group=1 if substr(population_of_interest, 1, 8)=="Incumbent" | substr(population_of_interest, 1, 4)=="MW +" | 
substr(population_of_interest, 1, 4)=="MW -" | substr(population_of_interest, 1, 8)=="Low wage" | substr(population_of_interest, 1, 8)=="Low-wage" | 
substr(population_of_interest, 1, 3)=="w <" | substr(population_of_interest, 1, 15)=="Workers in NLSY" | population_of_interest=="Overall, relative to sample avg MW increase" ;
tab population_of_interest if low_wage_group==1 ;
tab low_wage_group ;
tab author1 if low_wage_group==1 ;
sum elasticity if low_wage_group==1, detail ;
local median_elas=`r(p50)' ;
local median_elas=round(`median_elas', 0.001) ;
local mean_elas=`r(mean)' ;
local mean_elas=round(`mean_elas', 0.001) ;

sum elasticity if low_wage_group==1 & year_ref<2010, detail ;
local median_elas_bef_2010=`r(p50)' ;
local mean_elas_bef_2010=`r(mean)' ;

sum elasticity if low_wage_group==1 & year_ref>=2010, detail ;
local median_elas_2010_onw=`r(p50)' ;
local mean_elas_2010_onw=`r(mean)' ;

display "`median_elas_bef_2010' `median_elas_2010_onw' `mean_elas_bef_2010' `mean_elas_2010_onw'" ;
keep if low_wage_group==1 ;
tab groupname ;
sort neg_elas authorgroup ;
gen order=_n ;

decode paper, gen(paper_name) ;
replace paper_name="Kim & Taylor (1995)" if paper_name=="T Kim & Taylor (1995)" ;
replace paper_name="Kim & Jang (2020)" if paper_name=="HS Kim & Jang (2020)" ;
replace paper_name="Kandilov & Kandilov (forth.)" if paper_name=="Kandilov & Kandilov (forthcoming" ;
replace paper_name="Gopalan et al. (forth.)" if paper_name=="Gopalan et al. (forthcoming)" ;
replace paper_name="Bailey et al. (forth.)" if paper_name=="Bailey et al. (forthcoming)" ;
replace paper_name="Derenoncourt & Montialoux (forth.)" if paper_name=="Derenoncourt & Montialoux (forth" ;
replace paper_name="Gilyard & Podemska-Mikluch (2020)" if paper_name=="Gilyard & Podemska-Mikluch (2020" ;

count ;
forvalues y=1(1)`r(N)' { ;

	local paper`y'=paper_name[`y'] ;
	
} ;

count ;
count if elasticity<0 ;
count if elasticity<0 & (significance==".1" | significance==".05") ;
count if elasticity<0 & significance==".05" ;
count if elasticity>=0 ;
count if elasticity>=0 & (significance==".1" | significance==".05") ;
count if elasticity>=0 & significance==".05" ;

count if year_ref<2010 ;
count if elasticity<0 & year_ref<2010 ;
count if elasticity<0 & (significance==".1" | significance==".05") & year_ref<2010 ;
count if elasticity<0 & significance==".05" & year_ref<2010 ;
count if elasticity>=0 & year_ref<2010 ;
count if elasticity>=0 & (significance==".1" | significance==".05") & year_ref<2010 ;
count if elasticity>=0 & significance==".05" & year_ref<2010 ;

count if year_ref>=2010 ;
count if elasticity<0 & year_ref>=2010 ;
count if elasticity<0 & (significance==".1" | significance==".05") & year_ref>=2010 ;
count if elasticity<0 & significance==".05" & year_ref>=2010 ;
count if elasticity>=0 & year_ref>=2010 ;
count if elasticity>=0 & (significance==".1" | significance==".05") & year_ref>=2010 ;
count if elasticity>=0 & significance==".05" & year_ref>=2010 ;

display "Mean elasicity = `mean_elas'" ;
display "Median elasticity = `median_elas'" ;
twoway (bar elasticity order if significance=="No", horizontal color(gs12)) (bar elasticity order if significance==".1", horizontal color(gs6)) (bar elasticity order if significance==".05", horizontal color(gs0)), xscale(range(-1(0.1)0.6)) xlabel(-1(0.5)0.5) xmtick(-1(0.1)0.6) xline(0, lpattern(solid) lcolor(black) lwidth(medthick)) xline(`mean_elas', lpattern(dash) lcolor(black) lwidth(medthin)) xline(`median_elas', lpattern(dot) lcolor(black) lwidth(medthin))
ylabel(1 "`paper1'" 2 "`paper2'" 3 "`paper3'" 4 "`paper4'" 5 "`paper5'" 6 "`paper6'" 7 "`paper7'" 8 "`paper8'", angle(0) labsize(tiny))
ytitle("") xtitle("Elasticity Estimate", size(vsmall)) legend(label(1 "Insignificant") label(2 "Marginally (10%) Significant") label(3 "Statistically (5%) Significant")) legend(size(tiny)) legend(cols(1) rows(3)) legend(position(2) ring(0)) 
graphregion(color(white)) ;
graph export "${FIGURES}Figure12_Low_Wage_Explicit_Elasticities_Final.png", width(8000) replace ;
graph close ;

drop _all ;



use "${OUTPUT}MW_Papers_1992_2020_Final.dta" ;

drop if elasticity==. | significance=="" ;

gen low_ed=1 if substr(population_of_interest, 1, 5)=="16-29" | substr(population_of_interest, 1, 10)=="HS dropout" | substr(population_of_interest, 1, 4)=="HSDO" | substr(population_of_interest, 1, 10)=="HS or less" | 
substr(population_of_interest, 1, 20)=="High school dropouts" | substr(population_of_interest, 1, 9)=="Immigrants" | substr(population_of_interest, 1, 12)=="Non enrolled" | substr(population_of_interest, 1, 14)=="Single mothers" | 
substr(population_of_interest, 1, 25)=="Young adults, 16-29, LTHS" | substr(population_of_interest, 1, 31)=="Young adults, 20-24, HS or less"  | substr(population_of_interest, 1, 23)=="Teens 16-19, no college" ;
tab population_of_interest if low_ed==1 ;

tab low_ed ;
tab author1 if low_ed==1 ;
sum elasticity if low_ed==1, detail ;
local median_elas=`r(p50)' ;
local median_elas=round(`median_elas', 0.001) ;
local mean_elas=`r(mean)' ;
local mean_elas=round(`mean_elas', 0.001) ;

sum elasticity if low_ed==1 & year_ref<2010, detail ;
local median_elas_bef_2010=`r(p50)' ;
local mean_elas_bef_2010=`r(mean)' ;

sum elasticity if low_ed==1 & year_ref>=2010, detail ;
local median_elas_2010_onw=`r(p50)' ;
local mean_elas_2010_onw=`r(mean)' ;

display "`median_elas_bef_2010' `median_elas_2010_onw' `mean_elas_bef_2010' `mean_elas_2010_onw'" ;
keep if low_ed==1 ;
tab groupname ;
sort neg_elas authorgroup ;
gen order=_n ;

decode paper, gen(paper_name) ;
replace paper_name="Kim & Taylor (1995)" if paper_name=="T Kim & Taylor (1995)" ;
replace paper_name="Kim & Jang (2020)" if paper_name=="HS Kim & Jang (2020)" ;
replace paper_name="Kandilov & Kandilov (forth.)" if paper_name=="Kandilov & Kandilov (forthcoming" ;
replace paper_name="Gopalan et al. (forth.)" if paper_name=="Gopalan et al. (forthcoming)" ;
replace paper_name="Bailey et al. (forth.)" if paper_name=="Bailey et al. (forthcoming)" ;
replace paper_name="Derenoncourt & Montialoux (forth.)" if paper_name=="Derenoncourt & Montialoux (forth" ;
replace paper_name="Gilyard & Podemska-Mikluch (2020)" if paper_name=="Gilyard & Podemska-Mikluch (2020" ;

count ;
forvalues y=1(1)`r(N)' { ;

	local paper`y'=paper_name[`y'] ;
	
} ;

count ;
count if elasticity<0 ;
count if elasticity<0 & (significance==".1" | significance==".05") ;
count if elasticity<0 & significance==".05" ;
count if elasticity>=0 ;
count if elasticity>=0 & (significance==".1" | significance==".05") ;
count if elasticity>=0 & significance==".05" ;

count if year_ref<2010 ;
count if elasticity<0 & year_ref<2010 ;
count if elasticity<0 & (significance==".1" | significance==".05") & year_ref<2010 ;
count if elasticity<0 & significance==".05" & year_ref<2010 ;
count if elasticity>=0 & year_ref<2010 ;
count if elasticity>=0 & (significance==".1" | significance==".05") & year_ref<2010 ;
count if elasticity>=0 & significance==".05" & year_ref<2010 ;

count if year_ref>=2010 ;
count if elasticity<0 & year_ref>=2010 ;
count if elasticity<0 & (significance==".1" | significance==".05") & year_ref>=2010 ;
count if elasticity<0 & significance==".05" & year_ref>=2010 ;
count if elasticity>=0 & year_ref>=2010 ;
count if elasticity>=0 & (significance==".1" | significance==".05") & year_ref>=2010 ;
count if elasticity>=0 & significance==".05" & year_ref>=2010 ;

display "Mean elasicity = `mean_elas'" ;
display "Median elasticity = `median_elas'" ;
twoway (bar elasticity order if significance=="No", horizontal color(gs12)) (bar elasticity order if significance==".1", horizontal color(gs6)) (bar elasticity order if significance==".05", horizontal color(gs0)), xscale(range(-1(0.1)0.6)) xlabel(-1(0.5)0.5) xmtick(-1(0.1)0.6) xline(0, lpattern(solid) lcolor(black) lwidth(medthick)) xline(`mean_elas', lpattern(dash) lcolor(black) lwidth(medthin)) xline(`median_elas', lpattern(dot) lcolor(black) lwidth(medthin))
ylabel(1 "`paper1'" 2 "`paper2'" 3 "`paper3'" 4 "`paper4'" 5 "`paper5'" 6 "`paper6'" 7 "`paper7'" 8 "`paper8'" 9 "`paper9'" 10 "`paper10'" 11 "`paper11'" 12 "`paper12'" 13 "`paper13'" 14 "`paper14'", angle(0) labsize(tiny))
ytitle("") xtitle("Elasticity Estimate", size(vsmall)) legend(label(1 "Insignificant") label(2 "Marginally (10%) Significant") label(3 "Statistically (5%) Significant")) legend(size(tiny)) legend(cols(1) rows(3)) legend(position(2) ring(0)) 
graphregion(color(white)) ;
graph export "${FIGURES}Figure9_Low_Ed_Elasticities_Final.png", width(8000) replace ;
graph close ;

drop _all ;

/* Next, we'll look at the source of identifying variation. We have three primary
types in this data: federal changes, state changes, and case studies. */
use "${OUTPUT}MW_Papers_1992_2020_Final.dta" ;

drop if elasticity==. | significance=="" ;

gen federal=1 if substr(variation_type, 1, 7)=="Federal" ;
tab federal ;
sum elasticity if federal==1, detail ;
local median_elas=`r(p50)' ;
local median_elas=round(`median_elas', 0.001) ;
local mean_elas=`r(mean)' ;
local mean_elas=round(`mean_elas', 0.001) ;

sum elasticity if federal==1 & year_ref<2010, detail ;
local median_elas_bef_2010=`r(p50)' ;
local mean_elas_bef_2010=`r(mean)' ;

sum elasticity if federal==1 & year_ref>=2010, detail ;
local median_elas_2010_onw=`r(p50)' ;
local mean_elas_2010_onw=`r(mean)' ;

display "`median_elas_bef_2010' `median_elas_2010_onw' `mean_elas_bef_2010' `mean_elas_2010_onw'" ;
keep if federal==1 ;
tab groupname ;
sort neg_elas authorgroup ;
gen order=_n ;

decode paper, gen(paper_name) ;
replace paper_name="Kim & Taylor (1995)" if paper_name=="T Kim & Taylor (1995)" ;
replace paper_name="Kim & Jang (2020)" if paper_name=="HS Kim & Jang (2020)" ;
replace paper_name="Kandilov & Kandilov (forth.)" if paper_name=="Kandilov & Kandilov (forthcoming" ;
replace paper_name="Gopalan et al. (forth.)" if paper_name=="Gopalan et al. (forthcoming)" ;
replace paper_name="Bailey et al. (forth.)" if paper_name=="Bailey et al. (forthcoming)" ;
replace paper_name="Derenoncourt & Montialoux (forth.)" if paper_name=="Derenoncourt & Montialoux (forth" ;
replace paper_name="Gilyard & Podemska-Mikluch (2020)" if paper_name=="Gilyard & Podemska-Mikluch (2020" ;

count ;
forvalues y=1(1)`r(N)' { ;

	local paper`y'=paper_name[`y'] ;
	
} ;

count ;
count if elasticity<0 ;
count if elasticity<0 & (significance==".1" | significance==".05") ;
count if elasticity<0 & significance==".05" ;
count if elasticity>=0 ;
count if elasticity>=0 & (significance==".1" | significance==".05") ;
count if elasticity>=0 & significance==".05" ;

count if year_ref<2010 ;
count if elasticity<0 & year_ref<2010 ;
count if elasticity<0 & (significance==".1" | significance==".05") & year_ref<2010 ;
count if elasticity<0 & significance==".05" & year_ref<2010 ;
count if elasticity>=0 & year_ref<2010 ;
count if elasticity>=0 & (significance==".1" | significance==".05") & year_ref<2010 ;
count if elasticity>=0 & significance==".05" & year_ref<2010 ;

count if year_ref>=2010 ;
count if elasticity<0 & year_ref>=2010 ;
count if elasticity<0 & (significance==".1" | significance==".05") & year_ref>=2010 ;
count if elasticity<0 & significance==".05" & year_ref>=2010 ;
count if elasticity>=0 & year_ref>=2010 ;
count if elasticity>=0 & (significance==".1" | significance==".05") & year_ref>=2010 ;
count if elasticity>=0 & significance==".05" & year_ref>=2010 ;

display "Mean elasicity = `mean_elas'" ;
display "Median elasticity = `median_elas'" ;
twoway (bar elasticity order if significance=="No", horizontal color(gs12)) (bar elasticity order if significance==".1", horizontal color(gs6)) (bar elasticity order if significance==".05", horizontal color(gs0)), xscale(range(-1(0.1)1.8)) xlabel(-1(0.5)1.5) xmtick(-1(0.1)1.8) xline(0, lpattern(solid) lcolor(black) lwidth(medthick)) xline(`mean_elas', lpattern(dash) lcolor(black) lwidth(medthin)) xline(`median_elas', lpattern(dot) lcolor(black) lwidth(medthin))
ylabel(1 "`paper1'" 2 "`paper2'" 3 "`paper3'" 4 "`paper4'" 5 "`paper5'" 6 "`paper6'" 7 "`paper7'" 8 "`paper8'" 9 "`paper9'" 10 "`paper10'" 11 "`paper11'" 12 "`paper12'" 13 "`paper13'" 14 "`paper14'" 15 "`paper15'" 16 "`paper16'" 17 "`paper17'" 18 "`paper18'" 19 "`paper19'" 20 "`paper20'" 21 "`paper21'" 22 "`paper22'" 23 "`paper23'" 24 "`paper24'" 25 "`paper25'" 26 "`paper26'" 27 "`paper27'" 28 "`paper28'" 29 "`paper29'" 30 "`paper30'" 31 "`paper31'" 32 "`paper32'" 33 "`paper33'" 34 "`paper34'", angle(0) labsize(tiny))
ytitle("") xtitle("Elasticity Estimate", size(vsmall)) legend(label(1 "Insignificant") label(2 "Marginally (10%) Significant") label(3 "Statistically (5%) Significant")) legend(size(tiny)) legend(cols(1) rows(3)) legend(position(2) ring(0))
graphregion(color(white)) ;
graph export "${FIGURES}Figure4_Preferred_Federal_Var_Elasticities_Final.png", width(8000) replace ;
graph close ;

drop _all ;

use "${OUTPUT}MW_Papers_1992_2020_Final.dta" ;

drop if elasticity==. | significance=="" ;

gen state=1 if substr(variation_type, 1, 5)=="State" ;
tab state ;
sum elasticity if state==1, detail ;
local median_elas=`r(p50)' ;
local median_elas=round(`median_elas', 0.001) ;
local mean_elas=`r(mean)' ;
local mean_elas=round(`mean_elas', 0.001) ;

sum elasticity if state==1 & year_ref<2010, detail ;
local median_elas_bef_2010=`r(p50)' ;
local mean_elas_bef_2010=`r(mean)' ;

sum elasticity if state==1 & year_ref>=2010, detail ;
local median_elas_2010_onw=`r(p50)' ;
local mean_elas_2010_onw=`r(mean)' ;

display "`median_elas_bef_2010' `median_elas_2010_onw' `mean_elas_bef_2010' `mean_elas_2010_onw'" ;
keep if state==1 ;
tab groupname ;
sort neg_elas authorgroup ;
gen order=_n ;

decode paper, gen(paper_name) ;
replace paper_name="Kim & Taylor (1995)" if paper_name=="T Kim & Taylor (1995)" ;
replace paper_name="Kim & Jang (2020)" if paper_name=="HS Kim & Jang (2020)" ;
replace paper_name="Kandilov & Kandilov (forth.)" if paper_name=="Kandilov & Kandilov (forthcoming" ;
replace paper_name="Gopalan et al. (forth.)" if paper_name=="Gopalan et al. (forthcoming)" ;
replace paper_name="Bailey et al. (forth.)" if paper_name=="Bailey et al. (forthcoming)" ;
replace paper_name="Derenoncourt & Montialoux (forth.)" if paper_name=="Derenoncourt & Montialoux (forth" ;
replace paper_name="Gilyard & Podemska-Mikluch (2020)" if paper_name=="Gilyard & Podemska-Mikluch (2020" ;

count ;
forvalues y=1(1)`r(N)' { ;

	local paper`y'=paper_name[`y'] ;
	
} ;

count ;
count if elasticity<0 ;
count if elasticity<0 & (significance==".1" | significance==".05") ;
count if elasticity<0 & significance==".05" ;
count if elasticity>=0 ;
count if elasticity>=0 & (significance==".1" | significance==".05") ;
count if elasticity>=0 & significance==".05" ;

count if year_ref<2010 ;
count if elasticity<0 & year_ref<2010 ;
count if elasticity<0 & (significance==".1" | significance==".05") & year_ref<2010 ;
count if elasticity<0 & significance==".05" & year_ref<2010 ;
count if elasticity>=0 & year_ref<2010 ;
count if elasticity>=0 & (significance==".1" | significance==".05") & year_ref<2010 ;
count if elasticity>=0 & significance==".05" & year_ref<2010 ;

count if year_ref>=2010 ;
count if elasticity<0 & year_ref>=2010 ;
count if elasticity<0 & (significance==".1" | significance==".05") & year_ref>=2010 ;
count if elasticity<0 & significance==".05" & year_ref>=2010 ;
count if elasticity>=0 & year_ref>=2010 ;
count if elasticity>=0 & (significance==".1" | significance==".05") & year_ref>=2010 ;
count if elasticity>=0 & significance==".05" & year_ref>=2010 ;

display "Mean elasicity = `mean_elas'" ;
display "Median elasticity = `median_elas'" ;
twoway (bar elasticity order if significance=="No", horizontal color(gs12)) (bar elasticity order if significance==".1", horizontal color(gs6)) (bar elasticity order if significance==".05", horizontal color(gs0)), xscale(range(-1(0.1)0.6)) xlabel(-1(0.5)0.6) xmtick(-1(0.1)0.6) xline(0, lpattern(solid) lcolor(black) lwidth(medthick)) xline(`mean_elas', lpattern(dash) lcolor(black) lwidth(medthin)) xline(`median_elas', lpattern(dot) lcolor(black) lwidth(medthin))
ylabel(1 "`paper1'" 2 "`paper2'" 3 "`paper3'" 4 "`paper4'" 5 "`paper5'" 6 "`paper6'" 7 "`paper7'" 8 "`paper8'" 9 "`paper9'" 10 "`paper10'" 11 "`paper11'" 12 "`paper12'" 13 "`paper13'" 14 "`paper14'" 15 "`paper15'" 16 "`paper16'" 17 "`paper17'" 18 "`paper18'" 19 "`paper19'" 20 "`paper20'" 21 "`paper21'" 22 "`paper22'" 23 "`paper23'" 24 "`paper24'" 25 "`paper25'" 26 "`paper26'" 27 "`paper27'" 28 "`paper28'" 29 "`paper29'" 30 "`paper30'" 31 "`paper31'" 32 "`paper32'" 33 "`paper33'" 34 "`paper34'" 35 "`paper35'" 36 "`paper36'" 37 "`paper37'" 38 "`paper38'" 39 "`paper39'" 40 "`paper40'" 41 "`paper41'" 42 "`paper42'" 43 "`paper43'" 44 "`paper44'" 45 "`paper45'" 46 "`paper46'" 47 "`paper47'" 48 "`paper48'" 49 "`paper49'" 50 "`paper50'" 51 "`paper51'" 52 "`paper52'" 53 "`paper53'" 54 "`paper54'" 55 "`paper55'" 56 "`paper56'" 57 "`paper57'" 58 "`paper58'" 59 "`paper59'" 60 "`paper60'" 61 "`paper61'" 62 "`paper62'" 63 "`paper63'" 64 "`paper64'" 65 "`paper65'" 66 "`paper66'" 67 "`paper67'" 68 "`paper68'" 69 "`paper69'" 70 "`paper70'" 71 "`paper71'" 72 "`paper72'" 73 "`paper73'" 74 "`paper74'", angle(0) labsize(tiny))
ytitle("") xtitle("Elasticity Estimate", size(vsmall)) legend(label(1 "Insignificant") label(2 "Marginally (10%) Significant") label(3 "Statistically (5%) Significant")) legend(size(tiny)) legend(cols(1) rows(3)) legend(position(2) ring(0))
graphregion(color(white)) ;
graph export "${FIGURES}Figure5_Preferred_State_Var_Elasticities_Final.png", width(8000) replace ;
graph close ;

drop _all ;

use "${OUTPUT}MW_Papers_1992_2020_Final.dta" ;

drop if elasticity==. | significance=="" ;

gen casestudy=1 if substr(variation_type, 1, 10)=="Case-study" ;
tab casestudy ;
sum elasticity if casestudy==1, detail ;
local median_elas=`r(p50)' ;
local median_elas=round(`median_elas', 0.001) ;
local mean_elas=`r(mean)' ;
local mean_elas=round(`mean_elas', 0.001) ;

sum elasticity if casestudy==1 & year_ref<2010, detail ;
local median_elas_bef_2010=`r(p50)' ;
local mean_elas_bef_2010=`r(mean)' ;

sum elasticity if casestudy==1 & year_ref>=2010, detail ;
local median_elas_2010_onw=`r(p50)' ;
local mean_elas_2010_onw=`r(mean)' ;

display "`median_elas_bef_2010' `median_elas_2010_onw' `mean_elas_bef_2010' `mean_elas_2010_onw'" ;
keep if casestudy==1 ;
tab groupname ;
sort neg_elas authorgroup ;
gen order=_n ;

decode paper, gen(paper_name) ;
replace paper_name="Kim & Taylor (1995)" if paper_name=="T Kim & Taylor (1995)" ;
replace paper_name="Kim & Jang (2020)" if paper_name=="HS Kim & Jang (2020)" ;
replace paper_name="Kandilov & Kandilov (forth.)" if paper_name=="Kandilov & Kandilov (forthcoming" ;
replace paper_name="Gopalan et al. (forth.)" if paper_name=="Gopalan et al. (forthcoming)" ;
replace paper_name="Bailey et al. (forth.)" if paper_name=="Bailey et al. (forthcoming)" ;
replace paper_name="Derenoncourt & Montialoux (forth.)" if paper_name=="Derenoncourt & Montialoux (forth" ;
replace paper_name="Gilyard & Podemska-Mikluch (2020)" if paper_name=="Gilyard & Podemska-Mikluch (2020" ;

count ;
forvalues y=1(1)`r(N)' { ;

	local paper`y'=paper_name[`y'] ;
	
} ;

count ;
count if elasticity<0 ;
count if elasticity<0 & (significance==".1" | significance==".05") ;
count if elasticity<0 & significance==".05" ;
count if elasticity>=0 ;
count if elasticity>=0 & (significance==".1" | significance==".05") ;
count if elasticity>=0 & significance==".05" ;

count if year_ref<2010 ;
count if elasticity<0 & year_ref<2010 ;
count if elasticity<0 & (significance==".1" | significance==".05") & year_ref<2010 ;
count if elasticity<0 & significance==".05" & year_ref<2010 ;
count if elasticity>=0 & year_ref<2010 ;
count if elasticity>=0 & (significance==".1" | significance==".05") & year_ref<2010 ;
count if elasticity>=0 & significance==".05" & year_ref<2010 ;

count if year_ref>=2010 ;
count if elasticity<0 & year_ref>=2010 ;
count if elasticity<0 & (significance==".1" | significance==".05") & year_ref>=2010 ;
count if elasticity<0 & significance==".05" & year_ref>=2010 ;
count if elasticity>=0 & year_ref>=2010 ;
count if elasticity>=0 & (significance==".1" | significance==".05") & year_ref>=2010 ;
count if elasticity>=0 & significance==".05" & year_ref>=2010 ;

display "Mean elasicity = `mean_elas'" ;
display "Median elasticity = `median_elas'" ;
twoway (bar elasticity order if significance=="No", horizontal color(gs12)) (bar elasticity order if significance==".1", horizontal color(gs6)) (bar elasticity order if significance==".05", horizontal color(gs0)), xscale(range(-1(0.1)0.6)) xlabel(-1(0.5)0.6) xmtick(-1(0.1)0.6) xline(0, lpattern(solid) lcolor(black) lwidth(medthick)) xline(`mean_elas', lpattern(dash) lcolor(black) lwidth(medthin)) xline(`median_elas', lpattern(dot) lcolor(black) lwidth(medthin))
ylabel(1 "`paper1'" 2 "`paper2'" 3 "`paper3'" 4 "`paper4'" 5 "`paper5'" 6 "`paper6'" 7 "`paper7'" 8 "`paper8'" 9 "`paper9'" 10 "`paper10'" 11 "`paper11'" 12 "`paper12'" 13 "`paper13'" 14 "`paper14'" 15 "`paper15'" 16 "`paper16'" 17 "`paper17'" 18 "`paper18'" 19 "`paper19'" 20 "`paper20'", angle(0) labsize(tiny))
ytitle("") xtitle("Elasticity Estimate", size(vsmall)) legend(label(1 "Insignificant") label(2 "Marginally (10%) Significant") label(3 "Statistically (5%) Significant")) legend(size(tiny)) legend(cols(1) rows(3)) legend(position(2) ring(0))
graphregion(color(white)) ;
graph export "${FIGURES}Figure6_Preferred_Case-Study_Elasticities_Final.png", width(8000) replace ;
graph close ;

drop _all ;

/* Some papers have a much larger number of estimates relative to others. To 
remove the over-weighting of these papers, we keep only the median elasticity 
estimate from each paper. */
use "${OUTPUT}MW_Papers_1992_2020_Final.dta" ;

drop if elasticity==. | significance=="" ;

bysort paper: egen median_elas=median(elasticity) ;
gen signo=(significance=="No") ;
gen sig10=(significance==".1") ;
gen sig5=(significance==".05") ;
bysort paper: egen total_no=sum(signo) ;
bysort paper: egen total_10=sum(sig10) ;
bysort paper: egen total_5=sum(sig5) ;
gen median_sig="" ;
replace median_sig="No" if total_10+total_5<=total_no ;
replace median_sig=".1" if (total_10+total_5>total_no) & (total_5<=total_10+total_no) ;
replace median_sig=".05" if total_5>total_10+total_no ;
tab median_sig ;

drop elasticity neg_elas ;
rename median_elas elasticity ;
gen neg_elas=-elasticity ;

bysort paper: keep if _n==_N ;

sum elasticity, detail ;
local median_elas=`r(p50)' ;
local median_elas=round(`median_elas', 0.001) ;
local mean_elas=`r(mean)' ;
local mean_elas=round(`mean_elas', 0.001) ;

sum elasticity if year_ref<2010, detail ;
local median_elas_bef_2010=`r(p50)' ;
local mean_elas_bef_2010=`r(mean)' ;

sum elasticity if year_ref>=2010, detail ;
local median_elas_2010_onw=`r(p50)' ;
local mean_elas_2010_onw=`r(mean)' ;

display "`median_elas_bef_2010' `median_elas_2010_onw' `mean_elas_bef_2010' `mean_elas_2010_onw'" ;
sort neg_elas authorgroup ;
gen order=_n ;

decode paper, gen(paper_name) ;
replace paper_name="Kim & Taylor (1995)" if paper_name=="T Kim & Taylor (1995)" ;
replace paper_name="Kim & Jang (2020)" if paper_name=="HS Kim & Jang (2020)" ;
replace paper_name="Kandilov & Kandilov (forth.)" if paper_name=="Kandilov & Kandilov (forthcoming" ;
replace paper_name="Gopalan et al. (forth.)" if paper_name=="Gopalan et al. (forthcoming)" ;
replace paper_name="Bailey et al. (forth.)" if paper_name=="Bailey et al. (forthcoming)" ;
replace paper_name="Derenoncourt & Montialoux (forth.)" if paper_name=="Derenoncourt & Montialoux (forth" ;
replace paper_name="Gilyard & Podemska-Mikluch (2020)" if paper_name=="Gilyard & Podemska-Mikluch (2020" ;

count ;
forvalues y=1(1)`r(N)' { ;

	local paper`y'=paper_name[`y'] ;
	
} ;

count ;
count if elasticity<0 ;
count if elasticity<0 & (median_sig==".1" | median_sig==".05") ;
count if elasticity<0 & median_sig==".05" ;
count if elasticity>=0 ;
count if elasticity>=0 & (median_sig==".1" | median_sig==".05") ;
count if elasticity>=0 & median_sig==".05" ;

count if year_ref<2010 ;
count if elasticity<0 & year_ref<2010 ;
count if elasticity<0 & (median_sig==".1" | median_sig==".05") & year_ref<2010 ;
count if elasticity<0 & median_sig==".05" & year_ref<2010 ;
count if elasticity>=0 & year_ref<2010 ;
count if elasticity>=0 & (median_sig==".1" | median_sig==".05") & year_ref<2010 ;
count if elasticity>=0 & median_sig==".05" & year_ref<2010 ;

count if year_ref>=2010 ;
count if elasticity<0 & year_ref>=2010 ;
count if elasticity<0 & (median_sig==".1" | median_sig==".05") & year_ref>=2010 ;
count if elasticity<0 & median_sig==".05" & year_ref>=2010 ;
count if elasticity>=0 & year_ref>=2010 ;
count if elasticity>=0 & (median_sig==".1" | median_sig==".05") & year_ref>=2010 ;
count if elasticity>=0 & median_sig==".05" & year_ref>=2010 ;

display "Mean elasicity = `mean_elas'" ;
display "Median elasticity = `median_elas'" ;
twoway (bar elasticity order if median_sig=="No", horizontal color(gs12)) (bar elasticity order if median_sig==".1", horizontal color(gs6)) (bar elasticity order if median_sig==".05", horizontal color(gs0)), xscale(range(-1(0.1)1.8)) xlabel(-1(0.5)1.5) xmtick(-1(0.1)1.8) xline(0, lpattern(solid) lcolor(black) lwidth(medthick)) xline(`mean_elas', lpattern(dash) lcolor(black) lwidth(medthin)) xline(`median_elas', lpattern(dot) lcolor(black) lwidth(medthin))
ylabel(1 "`paper1'" 2 "`paper2'" 3 "`paper3'" 4 "`paper4'" 5 "`paper5'" 6 "`paper6'" 7 "`paper7'" 8 "`paper8'" 9 "`paper9'" 10 "`paper10'" 11 "`paper11'" 12 "`paper12'" 13 "`paper13'" 14 "`paper14'" 15 "`paper15'" 16 "`paper16'" 17 "`paper17'" 18 "`paper18'" 19 "`paper19'" 20 "`paper20'" 21 "`paper21'" 22 "`paper22'" 23 "`paper23'" 24 "`paper24'" 25 "`paper25'" 26 "`paper26'" 27 "`paper27'" 28 "`paper28'" 29 "`paper29'" 30 "`paper30'" 31 "`paper31'" 32 "`paper32'" 33 "`paper33'" 34 "`paper34'" 35 "`paper35'" 36 "`paper36'" 37 "`paper37'" 38 "`paper38'" 39 "`paper39'" 40 "`paper40'" 41 "`paper41'" 42 "`paper42'" 43 "`paper43'" 44 "`paper44'" 45 "`paper45'" 46 "`paper46'" 47 "`paper47'" 48 "`paper48'" 49 "`paper49'" 50 "`paper50'" 51 "`paper51'" 52 "`paper52'" 53 "`paper53'" 54 "`paper54'" 55 "`paper55'" 56 "`paper56'" 57 "`paper57'" 58 "`paper58'" 59 "`paper59'" 60 "`paper60'" 61 "`paper61'" 62 "`paper62'" 63 "`paper63'" 64 "`paper64'" 65 "`paper65'" 66 "`paper66'" 67 "`paper67'" 68 "`paper68'" 69 "`paper69'" 70 "`paper70'", angle(0) labsize(half_tiny))
ytitle("") xtitle("Median Elasticity Estimate", size(vsmall)) legend(label(1 "Insignificant") label(2 "Marginally (10%) Significant") label(3 "Statistically (5%) Significant")) legend(size(tiny)) legend(cols(1) rows(3)) legend(position(2) ring(0)) 
graphregion(color(white)) ;
graph export "${FIGURES}Figure3_Median_Paper_Elasticities_Final.png", width(8000) replace ;
graph close ;

drop _all ;

use "${OUTPUT}MW_Papers_1992_2020_Final.dta" ;

drop if elasticity==. | significance=="" ;

bysort paper: egen median_elas=median(elasticity) ;
bysort paper: egen ci_lower=min(elasticity) ;
bysort paper: egen ci_upper=max(elasticity) ;
drop elasticity neg_elas ;
rename median_elas elasticity ;
gen neg_elas=-elasticity ;

gen signo=(significance=="No") ;
gen sig10=(significance==".1") ;
gen sig5=(significance==".05") ;
bysort paper: egen total_no=sum(signo) ;
bysort paper: egen total_10=sum(sig10) ;
bysort paper: egen total_5=sum(sig5) ;
gen median_sig="" ;
replace median_sig="No" if total_10+total_5<=total_no ;
replace median_sig=".1" if (total_10+total_5>total_no) & (total_5<=total_10+total_no) ;
replace median_sig=".05" if total_5>total_10+total_no ;
tab median_sig ;

bysort paper: keep if _n==_N ;

sum elasticity, detail ;
local median_elas=`r(p50)' ;
local median_elas=round(`median_elas', 0.001) ;
local mean_elas=`r(mean)' ;
local mean_elas=round(`mean_elas', 0.001) ;

sum elasticity if year_ref<2010, detail ;
local median_elas_bef_2010=`r(p50)' ;
local mean_elas_bef_2010=`r(mean)' ;

sum elasticity if year_ref>=2010, detail ;
local median_elas_2010_onw=`r(p50)' ;
local mean_elas_2010_onw=`r(mean)' ;

display "`median_elas_bef_2010' `median_elas_2010_onw' `mean_elas_bef_2010' `mean_elas_2010_onw'" ;
sort neg_elas authorgroup ;
gen order=_n ;

decode paper, gen(paper_name) ;
replace paper_name="Kim & Taylor (1995)" if paper_name=="T Kim & Taylor (1995)" ;
replace paper_name="Kim & Jang (2020)" if paper_name=="HS Kim & Jang (2020)" ;
replace paper_name="Kandilov & Kandilov (forth.)" if paper_name=="Kandilov & Kandilov (forthcoming" ;
replace paper_name="Gopalan et al. (forth.)" if paper_name=="Gopalan et al. (forthcoming)" ;
replace paper_name="Bailey et al. (forth.)" if paper_name=="Bailey et al. (forthcoming)" ;
replace paper_name="Derenoncourt & Montialoux (forth.)" if paper_name=="Derenoncourt & Montialoux (forth" ;
replace paper_name="Gilyard & Podemska-Mikluch (2020)" if paper_name=="Gilyard & Podemska-Mikluch (2020" ;

count ;
forvalues y=1(1)`r(N)' { ;

	local paper`y'=paper_name[`y'] ;
	
} ;

count ;
count if elasticity<0 ;
count if elasticity<0 & (median_sig==".1" | median_sig==".05") ;
count if elasticity<0 & median_sig==".05" ;
count if elasticity>=0 ;
count if elasticity>=0 & (median_sig==".1" | median_sig==".05") ;
count if elasticity>=0 & median_sig==".05" ;

count if year_ref<2010 ;
count if elasticity<0 & year_ref<2010 ;
count if elasticity<0 & (median_sig==".1" | median_sig==".05") & year_ref<2010 ;
count if elasticity<0 & median_sig==".05" & year_ref<2010 ;
count if elasticity>=0 & year_ref<2010 ;
count if elasticity>=0 & (median_sig==".1" | median_sig==".05") & year_ref<2010 ;
count if elasticity>=0 & median_sig==".05" & year_ref<2010 ;

count if year_ref>=2010 ;
count if elasticity<0 & year_ref>=2010 ;
count if elasticity<0 & (median_sig==".1" | median_sig==".05") & year_ref>=2010 ;
count if elasticity<0 & median_sig==".05" & year_ref>=2010 ;
count if elasticity>=0 & year_ref>=2010 ;
count if elasticity>=0 & (median_sig==".1" | median_sig==".05") & year_ref>=2010 ;
count if elasticity>=0 & median_sig==".05" & year_ref>=2010 ;

display "Mean elasicity = `mean_elas'" ;
display "Median elasticity = `median_elas'" ;
twoway (bar elasticity order if median_sig=="No", horizontal color(gs12)) (bar elasticity order if median_sig==".1", horizontal color(gs6)) (bar elasticity order if median_sig==".05", horizontal color(gs0)) (rcap ci_lower ci_upper order, horizontal lcolor(gs10)), xscale(range(-1(0.1)1.8)) xlabel(-1(0.5)1.5) xmtick(-1(0.1)1.8) xline(0, lpattern(solid) lcolor(black) lwidth(medthick)) xline(`mean_elas', lpattern(dash) lcolor(black) lwidth(medthin)) xline(`median_elas', lpattern(dot) lcolor(black) lwidth(medthin))
ylabel(1 "`paper1'" 2 "`paper2'" 3 "`paper3'" 4 "`paper4'" 5 "`paper5'" 6 "`paper6'" 7 "`paper7'" 8 "`paper8'" 9 "`paper9'" 10 "`paper10'" 11 "`paper11'" 12 "`paper12'" 13 "`paper13'" 14 "`paper14'" 15 "`paper15'" 16 "`paper16'" 17 "`paper17'" 18 "`paper18'" 19 "`paper19'" 20 "`paper20'" 21 "`paper21'" 22 "`paper22'" 23 "`paper23'" 24 "`paper24'" 25 "`paper25'" 26 "`paper26'" 27 "`paper27'" 28 "`paper28'" 29 "`paper29'" 30 "`paper30'" 31 "`paper31'" 32 "`paper32'" 33 "`paper33'" 34 "`paper34'" 35 "`paper35'" 36 "`paper36'" 37 "`paper37'" 38 "`paper38'" 39 "`paper39'" 40 "`paper40'" 41 "`paper41'" 42 "`paper42'" 43 "`paper43'" 44 "`paper44'" 45 "`paper45'" 46 "`paper46'" 47 "`paper47'" 48 "`paper48'" 49 "`paper49'" 50 "`paper50'" 51 "`paper51'" 52 "`paper52'" 53 "`paper53'" 54 "`paper54'" 55 "`paper55'" 56 "`paper56'" 57 "`paper57'" 58 "`paper58'" 59 "`paper59'" 60 "`paper60'" 61 "`paper61'" 62 "`paper62'" 63 "`paper63'" 64 "`paper64'" 65 "`paper65'" 66 "`paper66'" 67 "`paper67'" 68 "`paper68'" 69 "`paper69'" 70 "`paper70'", angle(0) labsize(half_tiny))
ytitle("") xtitle("Median Elasticity Estimate", size(vsmall)) legend(label(1 "Insignificant") label(2 "Marginally (10%) Significant") label(3 "Statistically (5%) Significant") label(4 "Range")) legend(size(tiny)) legend(cols(1) rows(4)) legend(position(2) ring(0)) 
graphregion(color(white)) ;
graph export "${FIGURES}FigureA2_Median_Paper_Range_Elasticities_Final.png", width(8000) replace ;
graph close ;

drop _all ;
label drop _all ;

/* This section is for Appendix Figure A1 which shows the difference in our 
estimates selected versus those reported by the authors in response to our survey. */
import excel using "${INPUT}MW_Papers_1992_2020_Final.xlsx", firstrow sheet("Author_Selections") cellrange(A1:L132) ;

rename Preferredestimate elasticity ;
rename SignificantNo105 significance ;
rename Definitionofestimate estimate_details ;
rename Group population_of_interest ;
rename Sourceinpaper estimate_location ;
rename Typeofvariation variation_type ;

replace significance="" if significance=="N/A" ;
replace significance="" if significance=="No response" ;
replace significance="" if significance=="No response?" ;
replace significance="" if significance=="Refused to provide preferred estimate" ;
replace significance="No" if author1=="Michl" ;

replace variation_type="" if variation_type=="N/A" ;
replace variation_type="" if variation_type=="No response" ;
replace variation_type="" if variation_type=="No response?" ;
replace variation_type="" if variation_type=="Refused to provide preferred estimate" ;

gen estimate_id=_n ;

gen authors="" ;
replace authors=author1 if author1!="" & author2=="" & author3=="" & author4=="" ;
egen forreplace2=concat(author1 author2) if author1!="" & author2!="" & author3=="" & author4=="", punct(" & ") ;
replace authors=forreplace2 if author1!="" & author2!="" & author3=="" & author4=="" ;
drop forreplace2 ;
replace authors=author1 + " et al." if author1!="" & author2!="" & author3!="" & author4=="" ;
replace authors=author1 + " et al." if author1!="" & author2!="" & author3!="" & author4!="" ;
replace authors=author1 + " et al." if author1!="" & author2!="" & author3!="" & author4!="" ;
replace authors=author1 + " et al." if author1!="" & author2!="" & author3!="" & author4!="" ;

replace year="2021" if year=="forthcoming" ;
destring year, replace ;
egen yearmult=concat(year multiple) ;
replace yearmult="(" + yearmult + ")" ;
egen paper=concat(authors yearmult), punct(" ") ;
egen paper2=group(paper), label ;
drop paper ;
rename paper2 paper ;

gen year_ref=year ;

gen neg_elas=-elasticity ;

drop if elasticity==. | significance=="" ;

bysort paper: egen median_elas=median(elasticity) ;
gen signo=(significance=="No") ;
gen sig10=(significance==".1") ;
gen sig5=(significance==".05") ;
bysort paper: egen total_no=sum(signo) ;
bysort paper: egen total_10=sum(sig10) ;
bysort paper: egen total_5=sum(sig5) ;
gen median_sig="" ;
replace median_sig="No" if total_10+total_5<=total_no ;
replace median_sig=".1" if (total_10+total_5>total_no) & (total_5<=total_10+total_no) ;
replace median_sig=".05" if total_5>total_10+total_no ;
tab median_sig ;

drop elasticity neg_elas ;
rename median_elas elasticity ;
gen neg_elas=-elasticity ;

bysort paper: keep if _n==_N ;

save "${OUTPUT}Author_Median_Estimates_Final.dta", replace ;

drop _all ;
label drop _all ;

import excel using "${INPUT}MW_Papers_1992_2020_Final.xlsx", firstrow sheet("Our_Selections") cellrange(A1:L179) ;

rename Preferredestimate elasticity ;
rename SignificantNo105 significance ;
rename Definitionofestimate estimate_details ;
rename Group population_of_interest ;
rename Sourceinpaper estimate_location ;
rename Typeofvariation variation_type ;

replace significance="" if significance=="N/A" ;
replace significance="" if significance=="No response" ;
replace significance="" if significance=="No response?" ;
replace significance="" if significance=="Refused to provide preferred estimate" ;
replace significance="No" if author1=="Michl" ;

replace variation_type="" if variation_type=="N/A" ;
replace variation_type="" if variation_type=="No response" ;
replace variation_type="" if variation_type=="No response?" ;
replace variation_type="" if variation_type=="Refused to provide preferred estimate" ;

gen estimate_id=_n ;

gen authors="" ;
replace authors=author1 if author1!="" & author2=="" & author3=="" & author4=="" ;
egen forreplace2=concat(author1 author2) if author1!="" & author2!="" & author3=="" & author4=="", punct(" & ") ;
replace authors=forreplace2  if author1!="" & author2!="" & author3=="" & author4=="" ;
drop forreplace2 ;
replace authors=author1 + " et al." if author1!="" & author2!="" & author3!="" & author4=="" ;
replace authors=author1 + " et al." if author1!="" & author2!="" & author3!="" & author4!="" ;

replace year="2021" if year=="forth." ;
destring year, replace ;
egen yearmult=concat(year multiple) ;
replace yearmult="(" + yearmult + ")" ;
egen paper=concat(authors yearmult), punct(" ") ;
egen paper2=group(paper), label ;
drop paper ;
rename paper2 paper ;

gen neg_elas=-elasticity ;

drop if elasticity==. | significance=="" ;

bysort paper: egen median_elas_OurEsts=median(elasticity) ;
gen signo_OurEsts=(significance=="No") ;
gen sig10_OurEsts=(significance==".1") ;
gen sig5_OurEsts=(significance==".05") ;
bysort paper: egen total_no_OurEsts=sum(signo_OurEsts) ;
bysort paper: egen total_10_OurEsts=sum(sig10_OurEsts) ;
bysort paper: egen total_5_OurEsts=sum(sig5_OurEsts) ;
gen median_sig_OurEsts="" ;
replace median_sig_OurEsts="No" if total_10_OurEsts+total_5_OurEsts<=total_no_OurEsts ;
replace median_sig_OurEsts=".1" if (total_10_OurEsts+total_5_OurEsts>total_no_OurEsts) & (total_5_OurEsts<=total_10_OurEsts+total_no_OurEsts) ;
replace median_sig_OurEsts=".05" if total_5_OurEsts>total_10_OurEsts+total_no_OurEsts ;
tab median_sig_OurEsts ;

gen sig_OurEsts=0 if significance=="No" ;
replace sig_OurEsts=1 if significance==".1" ;
replace sig_OurEsts=2 if significance==".05" ;
bysort paper: egen modal_sig_OurEsts=mode(sig_OurEsts), minmode ;
tab modal_sig_OurEsts ;
replace modal_sig_OurEsts=floor(modal_sig_OurEsts) ;
tab modal_sig_OurEsts ;
drop elasticity significance neg_elas ;
rename median_elas_OurEsts elasticity_OurEsts ;
rename median_sig_OurEsts significance_med_OurEsts ;
gen significance_mod_OurEsts="" ;
replace significance_mod_OurEsts="No" if modal_sig_OurEsts==0 ;
replace significance_mod_OurEsts=".1" if modal_sig_OurEsts==1 ;
replace significance_mod_OurEsts=".05" if modal_sig_OurEsts==2 ;

bysort paper: keep if _n==_N ;

save "${OUTPUT}Our_Median_Estimates_Final.dta", replace ;

merge 1:1 paper using "${OUTPUT}Author_Median_Estimates_Final.dta" ;

tab authors if _merge==1 ;
tab authors if _merge==2 ;

drop if _merge!=3 ;
drop if author1=="Card" ;
drop if author1=="Katz" ;
drop if author1=="Williams" ;
drop if author1=="T Kim" ;
drop if author1=="Singell" ;
drop if author1=="Deere" ;
drop if author1=="Neumark" ;
drop if author1=="Dodson" ;

gen elas_diff=elasticity_OurEsts-elasticity ;
tab elasticity ;
tab elasticity_OurEsts ;

drop neg_elas ;
gen neg_elas=-elas_diff ;
sort neg_elas authors yearmult ;
gen order=_n ;

sum elas_diff, detail ;
local median_elas=`r(p50)' ;
local median_elas=round(`median_elas', 0.001) ;
local mean_elas=`r(mean)' ;
local mean_elas=round(`mean_elas', 0.001) ;

sum elas_diff if year_ref<2010, detail ;
local median_elas_bef_2010=`r(p50)' ;
local mean_elas_bef_2010=`r(mean)' ;

sum elas_diff if year_ref>=2010, detail ;
local median_elas_2010_onw=`r(p50)' ;
local mean_elas_2010_onw=`r(mean)' ;

display "`median_elas_bef_2010' `median_elas_2010_onw' `mean_elas_bef_2010' `mean_elas_2010_onw'" ;

decode paper, gen(paper_name) ;
replace paper_name="Kim & Taylor (1995)" if paper_name=="T Kim & Taylor (1995)" ;
replace paper_name="Kim & Jang (2020)" if paper_name=="HS Kim & Jang (2020)" ;
replace paper_name="Kandilov & Kandilov (forth.)" if paper_name=="Kandilov & Kandilov (forthcoming" ;
replace paper_name="Gopalan et al. (forth.)" if paper_name=="Gopalan et al. (forthcoming)" ;
replace paper_name="Gilyard & Podemska-Mikluch (2020)" if paper_name=="Gilyard & Podemska-Mikluch (2020" ;

count ;
forvalues y=1(1)`r(N)' { ;

	local paper`y'=paper_name[`y'] ;
	
} ;

display "Mean elasicity = `mean_elas'" ;
display "Median elasticity = `median_elas'" ;
twoway bar elas_diff order, horizontal color(gs12) xscale(range(-1(0.1)1.8)) xlabel(-1(0.5)1.5) xmtick(-1(0.1)1.8) xline(0, lpattern(solid) lcolor(black) lwidth(medthick)) xline(`mean_elas', lpattern(dash) lcolor(black) lwidth(medthin)) xline(`median_elas', lpattern(dot) lcolor(black) lwidth(medthin))
ylabel(1 "`paper1'" 2 "`paper2'" 3 "`paper3'" 4 "`paper4'" 5 "`paper5'" 6 "`paper6'" 7 "`paper7'" 8 "`paper8'" 9 "`paper9'" 10 "`paper10'" 11 "`paper11'" 12 "`paper12'" 13 "`paper13'" 14 "`paper14'" 15 "`paper15'" 16 "`paper16'" 17 "`paper17'" 18 "`paper18'" 19 "`paper19'" 20 "`paper20'" 21 "`paper21'" 22 "`paper22'" 23 "`paper23'" 24 "`paper24'" 25 "`paper25'" 26 "`paper26'" 27 "`paper27'" 28 "`paper28'" 29 "`paper29'" 30 "`paper30'" 31 "`paper31'" 32 "`paper32'" 33 "`paper33'" 34 "`paper34'" 35 "`paper35'" 36 "`paper36'" 37 "`paper37'" 38 "`paper38'" 39 "`paper39'" 40 "`paper40'" 41 "`paper41'" 42 "`paper42'" 43 "`paper43'" 44 "`paper44'" 45 "`paper45'" 46 "`paper46'" 47 "`paper47'" 48 "`paper48'", angle(0) labsize(half_tiny))
ytitle("") xtitle("Median Elasticity Estimate Difference", size(vsmall)) legend(label(1 "Insignificant") label(2 "Marginally (10%) Significant") label(3 "Statistically (5%) Significant")) legend(size(tiny)) legend(cols(1) rows(3)) legend(position(2) ring(0)) 
graphregion(color(white)) ;
graph export "${FIGURES}FigureA1_Diff_Median_Paper_Elasticities_Final.png", width(8000) replace ;
graph close ;

log close ;
